/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: firmware_update.proto */

#ifndef PROTOBUF_C_firmware_5fupdate_2eproto__INCLUDED
#define PROTOBUF_C_firmware_5fupdate_2eproto__INCLUDED

#include <protobuf-c/protobuf-c.h>

PROTOBUF_C__BEGIN_DECLS

#if PROTOBUF_C_VERSION_NUMBER < 1003000
# error This file was generated by a newer version of protoc-c which is incompatible with your libprotobuf-c headers. Please update your headers.
#elif 1005000 < PROTOBUF_C_MIN_COMPILER_VERSION
# error This file was generated by an older version of protoc-c which is incompatible with your libprotobuf-c headers. Please regenerate this file with a newer version of protoc-c.
#endif


typedef struct Logi__Device__Proto__UpdateNowRequest Logi__Device__Proto__UpdateNowRequest;
typedef struct Logi__Device__Proto__UpdateNowResponse Logi__Device__Proto__UpdateNowResponse;


/* --- enums --- */


/* --- messages --- */

/*
 **
 * Request to start update
 * This is to be included in UsbMsg
 * EXPECTED RESPONSE
 * UpdateNowResponse
 */
struct  Logi__Device__Proto__UpdateNowRequest
{
  ProtobufCMessage base;
  /*
   **
   * Unused. Reserved for future use.
   */
  protobuf_c_boolean reserved;
};
#define LOGI__DEVICE__PROTO__UPDATE_NOW_REQUEST__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&logi__device__proto__update_now_request__descriptor) \
, 0 }


/*
 **
 * Update now response
 */
struct  Logi__Device__Proto__UpdateNowResponse
{
  ProtobufCMessage base;
  /*
   **
   * bool value to indicate update was started
   */
  protobuf_c_boolean started;
};
#define LOGI__DEVICE__PROTO__UPDATE_NOW_RESPONSE__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&logi__device__proto__update_now_response__descriptor) \
, 0 }


/* Logi__Device__Proto__UpdateNowRequest methods */
void   logi__device__proto__update_now_request__init
                     (Logi__Device__Proto__UpdateNowRequest         *message);
size_t logi__device__proto__update_now_request__get_packed_size
                     (const Logi__Device__Proto__UpdateNowRequest   *message);
size_t logi__device__proto__update_now_request__pack
                     (const Logi__Device__Proto__UpdateNowRequest   *message,
                      uint8_t             *out);
size_t logi__device__proto__update_now_request__pack_to_buffer
                     (const Logi__Device__Proto__UpdateNowRequest   *message,
                      ProtobufCBuffer     *buffer);
Logi__Device__Proto__UpdateNowRequest *
       logi__device__proto__update_now_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   logi__device__proto__update_now_request__free_unpacked
                     (Logi__Device__Proto__UpdateNowRequest *message,
                      ProtobufCAllocator *allocator);
/* Logi__Device__Proto__UpdateNowResponse methods */
void   logi__device__proto__update_now_response__init
                     (Logi__Device__Proto__UpdateNowResponse         *message);
size_t logi__device__proto__update_now_response__get_packed_size
                     (const Logi__Device__Proto__UpdateNowResponse   *message);
size_t logi__device__proto__update_now_response__pack
                     (const Logi__Device__Proto__UpdateNowResponse   *message,
                      uint8_t             *out);
size_t logi__device__proto__update_now_response__pack_to_buffer
                     (const Logi__Device__Proto__UpdateNowResponse   *message,
                      ProtobufCBuffer     *buffer);
Logi__Device__Proto__UpdateNowResponse *
       logi__device__proto__update_now_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   logi__device__proto__update_now_response__free_unpacked
                     (Logi__Device__Proto__UpdateNowResponse *message,
                      ProtobufCAllocator *allocator);
/* --- per-message closures --- */

typedef void (*Logi__Device__Proto__UpdateNowRequest_Closure)
                 (const Logi__Device__Proto__UpdateNowRequest *message,
                  void *closure_data);
typedef void (*Logi__Device__Proto__UpdateNowResponse_Closure)
                 (const Logi__Device__Proto__UpdateNowResponse *message,
                  void *closure_data);

/* --- services --- */


/* --- descriptors --- */

extern const ProtobufCMessageDescriptor logi__device__proto__update_now_request__descriptor;
extern const ProtobufCMessageDescriptor logi__device__proto__update_now_response__descriptor;

PROTOBUF_C__END_DECLS


#endif  /* PROTOBUF_C_firmware_5fupdate_2eproto__INCLUDED */
