/* auto-generated, do not modify */
#include "config.h"

#include "fu-fpc-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

/* getters */
/**
 * fu_struct_fpc_dfu_get_status: (skip):
 **/
guint8
fu_struct_fpc_dfu_get_status(const GByteArray *st)
{
    g_return_val_if_fail(st != NULL, 0x0);
    return st->data[0];
}
/**
 * fu_struct_fpc_dfu_get_max_payload_size: (skip):
 **/
guint8
fu_struct_fpc_dfu_get_max_payload_size(const GByteArray *st)
{
    g_return_val_if_fail(st != NULL, 0x0);
    return st->data[1];
}
/**
 * fu_struct_fpc_dfu_get_state: (skip):
 **/
FuFpcDfuState
fu_struct_fpc_dfu_get_state(const GByteArray *st)
{
    g_return_val_if_fail(st != NULL, 0x0);
    return st->data[4];
}

/* setters */
/**
 * fu_struct_fpc_dfu_set_status: (skip):
 **/
void
fu_struct_fpc_dfu_set_status(GByteArray *st, guint8 value)
{
    g_return_if_fail(st != NULL);
    st->data[0] = value;
}
/**
 * fu_struct_fpc_dfu_set_max_payload_size: (skip):
 **/
void
fu_struct_fpc_dfu_set_max_payload_size(GByteArray *st, guint8 value)
{
    g_return_if_fail(st != NULL);
    st->data[1] = value;
}
/**
 * fu_struct_fpc_dfu_set_state: (skip):
 **/
void
fu_struct_fpc_dfu_set_state(GByteArray *st, FuFpcDfuState value)
{
    g_return_if_fail(st != NULL);
    st->data[4] = value;
}
/**
 * fu_struct_fpc_dfu_new: (skip):
 **/
GByteArray *
fu_struct_fpc_dfu_new(void)
{
    GByteArray *st = g_byte_array_sized_new(6);
    fu_byte_array_set_size(st, 6, 0x0);
    return st;
}
