/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: device_time.proto */

#ifndef PROTOBUF_C_device_5ftime_2eproto__INCLUDED
#define PROTOBUF_C_device_5ftime_2eproto__INCLUDED

#include <protobuf-c/protobuf-c.h>

PROTOBUF_C__BEGIN_DECLS

#if PROTOBUF_C_VERSION_NUMBER < 1003000
# error This file was generated by a newer version of protoc-c which is incompatible with your libprotobuf-c headers. Please update your headers.
#elif 1005000 < PROTOBUF_C_MIN_COMPILER_VERSION
# error This file was generated by an older version of protoc-c which is incompatible with your libprotobuf-c headers. Please regenerate this file with a newer version of protoc-c.
#endif


typedef struct Logi__Device__Proto__SetDeviceTimeRequest Logi__Device__Proto__SetDeviceTimeRequest;


/* --- enums --- */


/* --- messages --- */

/*
 **
 * Request for setting device time
 * This is to be included in UsbMsg
 */
struct  Logi__Device__Proto__SetDeviceTimeRequest
{
  ProtobufCMessage base;
  /*
   **
   * utc timestamp.
   */
  uint64_t ts;
  /*
   **
   * the time zone.
   */
  char *time_zone;
};
#define LOGI__DEVICE__PROTO__SET_DEVICE_TIME_REQUEST__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&logi__device__proto__set_device_time_request__descriptor) \
, 0, (char *)protobuf_c_empty_string }


/* Logi__Device__Proto__SetDeviceTimeRequest methods */
void   logi__device__proto__set_device_time_request__init
                     (Logi__Device__Proto__SetDeviceTimeRequest         *message);
size_t logi__device__proto__set_device_time_request__get_packed_size
                     (const Logi__Device__Proto__SetDeviceTimeRequest   *message);
size_t logi__device__proto__set_device_time_request__pack
                     (const Logi__Device__Proto__SetDeviceTimeRequest   *message,
                      uint8_t             *out);
size_t logi__device__proto__set_device_time_request__pack_to_buffer
                     (const Logi__Device__Proto__SetDeviceTimeRequest   *message,
                      ProtobufCBuffer     *buffer);
Logi__Device__Proto__SetDeviceTimeRequest *
       logi__device__proto__set_device_time_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   logi__device__proto__set_device_time_request__free_unpacked
                     (Logi__Device__Proto__SetDeviceTimeRequest *message,
                      ProtobufCAllocator *allocator);
/* --- per-message closures --- */

typedef void (*Logi__Device__Proto__SetDeviceTimeRequest_Closure)
                 (const Logi__Device__Proto__SetDeviceTimeRequest *message,
                  void *closure_data);

/* --- services --- */


/* --- descriptors --- */

extern const ProtobufCMessageDescriptor logi__device__proto__set_device_time_request__descriptor;

PROTOBUF_C__END_DECLS


#endif  /* PROTOBUF_C_device_5ftime_2eproto__INCLUDED */
