/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_COLORHUG_ERROR_NONE,
    FU_COLORHUG_ERROR_UNKNOWN_CMD,
    FU_COLORHUG_ERROR_WRONG_UNLOCK_CODE,
    FU_COLORHUG_ERROR_NOT_IMPLEMENTED,
    FU_COLORHUG_ERROR_UNDERFLOW_SENSOR,
    FU_COLORHUG_ERROR_NO_SERIAL,
    FU_COLORHUG_ERROR_WATCHDOG,
    FU_COLORHUG_ERROR_INVALID_ADDRESS,
    FU_COLORHUG_ERROR_INVALID_LENGTH,
    FU_COLORHUG_ERROR_INVALID_CHECKSUM,
    FU_COLORHUG_ERROR_INVALID_VALUE,
    FU_COLORHUG_ERROR_UNKNOWN_CMD_FOR_BOOTLOADER,
    FU_COLORHUG_ERROR_NO_CALIBRATION,
    FU_COLORHUG_ERROR_OVERFLOW_MULTIPLY,
    FU_COLORHUG_ERROR_OVERFLOW_ADDITION,
    FU_COLORHUG_ERROR_OVERFLOW_SENSOR,
    FU_COLORHUG_ERROR_OVERFLOW_STACK,
    FU_COLORHUG_ERROR_DEVICE_DEACTIVATED,
    FU_COLORHUG_ERROR_INCOMPLETE_REQUEST,
    FU_COLORHUG_ERROR_SELF_TEST_SENSOR,
    FU_COLORHUG_ERROR_SELF_TEST_RED,
    FU_COLORHUG_ERROR_SELF_TEST_GREEN,
    FU_COLORHUG_ERROR_SELF_TEST_BLUE,
    FU_COLORHUG_ERROR_SELF_TEST_COLOR_SELECT,
    FU_COLORHUG_ERROR_SELF_TEST_MULTIPLIER,
    FU_COLORHUG_ERROR_INVALID_CALIBRATION,
    FU_COLORHUG_ERROR_SRAM_FAILED,
    FU_COLORHUG_ERROR_OUT_OF_MEMORY,
    FU_COLORHUG_ERROR_SELF_TEST_TEMPERATURE,
    FU_COLORHUG_ERROR_SELF_TEST_I2C,
    FU_COLORHUG_ERROR_SELF_TEST_ADC_VDD,
    FU_COLORHUG_ERROR_SELF_TEST_ADC_VSS,
    FU_COLORHUG_ERROR_SELF_TEST_ADC_VREF,
    FU_COLORHUG_ERROR_I2C_TARGET_ADDRESS,
    FU_COLORHUG_ERROR_I2C_TARGET_CONFIG,
    FU_COLORHUG_ERROR_SELF_TEST_EEPROM,
} FuColorhugError;
const gchar *fu_colorhug_error_to_string(FuColorhugError val);
