/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>

GByteArray *fu_struct_sbat_level_section_header_parse_bytes(GBytes *blob, gsize offset, GError **error);
guint32 fu_struct_sbat_level_section_header_get_previous(const GByteArray *st);
guint32 fu_struct_sbat_level_section_header_get_latest(const GByteArray *st);
#define FU_STRUCT_SBAT_LEVEL_SECTION_HEADER_OFFSET_VERSION 0x0
#define FU_STRUCT_SBAT_LEVEL_SECTION_HEADER_OFFSET_PREVIOUS 0x4
#define FU_STRUCT_SBAT_LEVEL_SECTION_HEADER_OFFSET_LATEST 0x8
#define FU_STRUCT_SBAT_LEVEL_SECTION_HEADER_SIZE 0xC
#define FU_STRUCT_SBAT_LEVEL_SECTION_HEADER_DEFAULT_VERSION 0x0
