/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_TI_TPS6598X_SFWI_SUCCESS = 0x0,
    FU_TI_TPS6598X_SFWI_FAIL_FLASH_ERROR_OR_BUSY = 0x4,
    FU_TI_TPS6598X_SFWI_FAIL_FLASH_INVALID_ADDRESS = 0x5,
    FU_TI_TPS6598X_SFWI_FAIL_LAST_BOOT_WAS_UART = 0x6,
    FU_TI_TPS6598X_SFWI_FAIL_SFWI_AFTER_COMPLETE = 0x7,
    FU_TI_TPS6598X_SFWI_FAIL_NO_VALID_FLASH_REGION = 0x8,
    FU_TI_TPS6598X_SFWI_FAIL_UNKNOWN_ERROR = 0xF,
} FuTiTps6598xSfwi;
const gchar *fu_ti_tps6598x_sfwi_to_string(FuTiTps6598xSfwi val);
typedef enum {
    FU_TI_TPS6598X_SFWD_SUCCESS = 0x0,
    FU_TI_TPS6598X_SFWD_FAIL_FLASH_ERASE_WRITE_ERROR = 0x4,
    FU_TI_TPS6598X_SFWD_FAIL_SFWI_NOT_RUN_FIRST = 0x6,
    FU_TI_TPS6598X_SFWD_FAIL_TOO_MUCH_DATA = 0x7,
    FU_TI_TPS6598X_SFWD_FAIL_ID_NOT_IN_HEADER = 0x8,
    FU_TI_TPS6598X_SFWD_FAIL_BINARY_TOO_LARGE = 0x9,
    FU_TI_TPS6598X_SFWD_FAIL_DEVICE_ID_MISMATCH = 0xA,
    FU_TI_TPS6598X_SFWD_FAIL_FLASH_ERROR_READ_ONLY = 0xD,
    FU_TI_TPS6598X_SFWD_FAIL_UNKNOWN_ERROR = 0xF,
} FuTiTps6598xSfwd;
const gchar *fu_ti_tps6598x_sfwd_to_string(FuTiTps6598xSfwd val);
typedef enum {
    FU_TI_TPS6598X_SFWS_SUCCESS = 0x0,
    FU_TI_TPS6598X_SFWS_FAIL_FLASH_ERASE_WRITE_ERROR = 0x4,
    FU_TI_TPS6598X_SFWS_FAIL_SFWD_NOT_RUN_OR_NO_KEY_EXISTS = 0x6,
    FU_TI_TPS6598X_SFWS_FAIL_TOO_MUCH_DATA = 0x7,
    FU_TI_TPS6598X_SFWS_FAIL_CRC_FAIL = 0x8,
    FU_TI_TPS6598X_SFWS_FAIL_DID_CHECK_FAIL = 0x9,
    FU_TI_TPS6598X_SFWS_FAIL_VERSION_CHECK_FAIL = 0xA,
    FU_TI_TPS6598X_SFWS_FAIL_NO_HASH_MATCH_RULE_SATISFIED = 0xB,
    FU_TI_TPS6598X_SFWS_FAIL_ENGR_FW_UPDATE_ATTEMPT_WHILE_RUNNING_PROD = 0xC,
    FU_TI_TPS6598X_SFWS_FAIL_INCOMPATIBLE_ROM_VERSION = 0xD,
    FU_TI_TPS6598X_SFWS_FAIL_CRC_BUSY = 0xE,
    FU_TI_TPS6598X_SFWS_FAIL_UNKNOWN_ERROR = 0xF,
} FuTiTps6598xSfws;
const gchar *fu_ti_tps6598x_sfws_to_string(FuTiTps6598xSfws val);
