/* auto-generated, do not modify */
#include "config.h"

#include "fu-analogix-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_analogix_update_status_to_string(FuAnalogixUpdateStatus val)
{
    if (val == FU_ANALOGIX_UPDATE_STATUS_INVALID)
        return "invalid";
    if (val == FU_ANALOGIX_UPDATE_STATUS_START)
        return "start";
    if (val == FU_ANALOGIX_UPDATE_STATUS_FINISH)
        return "finish";
    if (val == FU_ANALOGIX_UPDATE_STATUS_ERROR)
        return "error";
    return NULL;
}
