/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>

GByteArray *fu_struct_qc_fw_update_hdr_parse_bytes(GBytes *blob, gsize offset, GError **error);
gboolean fu_struct_qc_fw_update_hdr_validate_bytes(GBytes *blob, gsize offset, GError **error);
guint8 fu_struct_qc_fw_update_hdr_get_protocol(const GByteArray *st);
guint32 fu_struct_qc_fw_update_hdr_get_length(const GByteArray *st);
const guint8 *fu_struct_qc_fw_update_hdr_get_dev_variant(const GByteArray *st, gsize *bufsz);
guint16 fu_struct_qc_fw_update_hdr_get_major(const GByteArray *st);
guint16 fu_struct_qc_fw_update_hdr_get_minor(const GByteArray *st);
guint16 fu_struct_qc_fw_update_hdr_get_upgrades(const GByteArray *st);
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_MAGIC1 0x0
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_MAGIC2 0x4
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_MAGIC3 0x6
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_PROTOCOL 0x7
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_LENGTH 0x8
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_DEV_VARIANT 0xC
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_MAJOR 0x14
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_MINOR 0x16
#define FU_STRUCT_QC_FW_UPDATE_HDR_OFFSET_UPGRADES 0x18
#define FU_STRUCT_QC_FW_UPDATE_HDR_SIZE_DEV_VARIANT 0x8
#define FU_STRUCT_QC_FW_UPDATE_HDR_SIZE 0x1A
#define FU_STRUCT_QC_FW_UPDATE_HDR_DEFAULT_MAGIC1 0x41505055
#define FU_STRUCT_QC_FW_UPDATE_HDR_DEFAULT_MAGIC2 0x4844
#define FU_STRUCT_QC_FW_UPDATE_HDR_DEFAULT_MAGIC3 0x52
