/* auto-generated, do not modify */
#include "config.h"

#include "fu-linux-lockdown-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_linux_lockdown_to_string(FuLinuxLockdown val)
{
    if (val == FU_LINUX_LOCKDOWN_UNKNOWN)
        return "unknown";
    if (val == FU_LINUX_LOCKDOWN_INVALID)
        return "invalid";
    if (val == FU_LINUX_LOCKDOWN_NONE)
        return "none";
    if (val == FU_LINUX_LOCKDOWN_INTEGRITY)
        return "integrity";
    if (val == FU_LINUX_LOCKDOWN_CONFIDENTIALITY)
        return "confidentiality";
    return NULL;
}
