/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_CORSAIR_DEVICE_KIND_UNKNOWN,
    FU_CORSAIR_DEVICE_KIND_MOUSE,
    FU_CORSAIR_DEVICE_KIND_RECEIVER,
} FuCorsairDeviceKind;
const gchar *fu_corsair_device_kind_to_string(FuCorsairDeviceKind val);
FuCorsairDeviceKind fu_corsair_device_kind_from_string(const gchar *val);
