/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_DDC_OPCODE_GET_VCP = 0x01,
    FU_DDC_OPCODE_REQ = 0xCC,
} FuDdcOpcode;
typedef enum {
    FU_DDC_VCP_CODE_CONTROLLER_TYPE = 0xC8,
    FU_DDC_VCP_CODE_PRIORITY = 0x90,
    FU_DDC_VCP_CODE_UPDATE_PREP = 0xF2,
    FU_DDC_VCP_CODE_UPDATE_ACK = 0xF3,
    FU_DDC_VCP_CODE_SET_DATA = 0xF4,
    FU_DDC_VCP_CODE_GET_STAGED = 0xF5,
    FU_DDC_VCP_CODE_SET_DATA_FF = 0xF6,
    FU_DDC_VCP_CODE_COMMIT_FW = 0xF7,
    FU_DDC_VCP_CODE_GET_ISP_MODE = 0xF8,
    FU_DDC_VCP_CODE_REBOOT = 0xFB,
    FU_DDC_VCP_CODE_SUM = 0xFE,
    FU_DDC_VCP_CODE_VERSION = 0xFF,
} FuDdcVcpCode;
typedef enum {
    FU_DDC_I2C_ADDR_DISPLAY_DEVICE = 0x6E,
    FU_DDC_I2C_ADDR_HOST_DEVICE = 0x51,
    FU_DDC_I2C_ADDR_CHECKSUM = 0x50,
} FuDdcI2cAddr;
typedef enum {
    FU_DDCCI_PRIORITY_NORMAL,
    FU_DDCCI_PRIORITY_UP,
} FuDdcciPriority;
const gchar *fu_ddcci_priority_to_string(FuDdcciPriority val);

GByteArray *fu_struct_ddc_cmd_new(void);
void fu_struct_ddc_cmd_set_opcode(GByteArray *st, FuDdcOpcode value);
void fu_struct_ddc_cmd_set_vcp_code(GByteArray *st, FuDdcVcpCode value);
#define FU_STRUCT_DDC_CMD_OFFSET_OPCODE 0x0
#define FU_STRUCT_DDC_CMD_OFFSET_VCP_CODE 0x1
#define FU_STRUCT_DDC_CMD_SIZE 0x2
#define FU_STRUCT_DDC_CMD_DEFAULT_OPCODE FU_DDC_OPCODE_REQ
