/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_MEI_FAMILY_UNKNOWN,
    FU_MEI_FAMILY_SPS,
    FU_MEI_FAMILY_TXE,
    FU_MEI_FAMILY_ME,
    FU_MEI_FAMILY_CSME,
} FuMeiFamily;
const gchar *fu_mei_family_to_string(FuMeiFamily val);
typedef enum {
    FU_ME_HFS_CWS_RESET,
    FU_ME_HFS_CWS_INITIALIZING,
    FU_ME_HFS_CWS_RECOVERY,
    FU_ME_HFS_CWS_TEST,
    FU_ME_HFS_CWS_DISABLED,
    FU_ME_HFS_CWS_NORMAL,
    FU_ME_HFS_CWS_WAIT,
    FU_ME_HFS_CWS_TRANSITION,
    FU_ME_HFS_CWS_INVALID,
} FuMeHfsCws;
const gchar *fu_me_hfs_cws_to_string(FuMeHfsCws val);
typedef enum {
    FU_ME_HFS_STATE_PREBOOT,
    FU_ME_HFS_STATE_M0_WITH_UMA = 1,
    FU_ME_HFS_STATE_M3_WITHOUT_UMA = 4,
    FU_ME_HFS_STATE_M0_WITHOUT_UMA = 5,
    FU_ME_HFS_STATE_BRING_UP = 6,
    FU_ME_HFS_STATE_ERROR = 7,
} FuMeHfsState;
const gchar *fu_me_hfs_state_to_string(FuMeHfsState val);
typedef enum {
    FU_ME_HFS_MODE_NORMAL,
    FU_ME_HFS_MODE_DEBUG = 2,
    FU_ME_HFS_MODE_DISABLE,
    FU_ME_HFS_MODE_OVERRIDE_JUMPER,
    FU_ME_HFS_MODE_OVERRIDE_MEI,
    FU_ME_HFS_MODE_UNKNOWN6,
    FU_ME_HFS_MODE_MAYBE_SPS,
} FuMeHfsMode;
const gchar *fu_me_hfs_mode_to_string(FuMeHfsMode val);
typedef enum {
    FU_ME_HFS_ERROR_NO_ERROR,
    FU_ME_HFS_ERROR_UNCATEGORIZED_FAILURE,
    FU_ME_HFS_ERROR_DISABLED,
    FU_ME_HFS_ERROR_IMAGE_FAILURE,
    FU_ME_HFS_ERROR_DEBUG_FAILURE,
} FuMeHfsError;
const gchar *fu_me_hfs_error_to_string(FuMeHfsError val);
typedef enum {
    FU_ME_HFS_ENFORCEMENT_POLICY_NOTHING,
    FU_ME_HFS_ENFORCEMENT_POLICY_SHUTDOWN_TO,
    FU_ME_HFS_ENFORCEMENT_POLICY_SHUTDOWN_NOW,
    FU_ME_HFS_ENFORCEMENT_POLICY_SHUTDOWN_30MINS,
} FuMeHfsEnforcementPolicy;
