/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: device_mode.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "device_mode.pb-c.h"
void   logi__device__proto__transition_to_device_mode_request__init
                     (Logi__Device__Proto__TransitionToDeviceModeRequest         *message)
{
  static const Logi__Device__Proto__TransitionToDeviceModeRequest init_value = LOGI__DEVICE__PROTO__TRANSITION_TO_DEVICE_MODE_REQUEST__INIT;
  *message = init_value;
}
size_t logi__device__proto__transition_to_device_mode_request__get_packed_size
                     (const Logi__Device__Proto__TransitionToDeviceModeRequest *message)
{
  assert(message->base.descriptor == &logi__device__proto__transition_to_device_mode_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__transition_to_device_mode_request__pack
                     (const Logi__Device__Proto__TransitionToDeviceModeRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__transition_to_device_mode_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__transition_to_device_mode_request__pack_to_buffer
                     (const Logi__Device__Proto__TransitionToDeviceModeRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__transition_to_device_mode_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__TransitionToDeviceModeRequest *
       logi__device__proto__transition_to_device_mode_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__TransitionToDeviceModeRequest *)
     protobuf_c_message_unpack (&logi__device__proto__transition_to_device_mode_request__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__transition_to_device_mode_request__free_unpacked
                     (Logi__Device__Proto__TransitionToDeviceModeRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__transition_to_device_mode_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   logi__device__proto__transition_to_device_mode_response__init
                     (Logi__Device__Proto__TransitionToDeviceModeResponse         *message)
{
  static const Logi__Device__Proto__TransitionToDeviceModeResponse init_value = LOGI__DEVICE__PROTO__TRANSITION_TO_DEVICE_MODE_RESPONSE__INIT;
  *message = init_value;
}
size_t logi__device__proto__transition_to_device_mode_response__get_packed_size
                     (const Logi__Device__Proto__TransitionToDeviceModeResponse *message)
{
  assert(message->base.descriptor == &logi__device__proto__transition_to_device_mode_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__transition_to_device_mode_response__pack
                     (const Logi__Device__Proto__TransitionToDeviceModeResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__transition_to_device_mode_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__transition_to_device_mode_response__pack_to_buffer
                     (const Logi__Device__Proto__TransitionToDeviceModeResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__transition_to_device_mode_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__TransitionToDeviceModeResponse *
       logi__device__proto__transition_to_device_mode_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__TransitionToDeviceModeResponse *)
     protobuf_c_message_unpack (&logi__device__proto__transition_to_device_mode_response__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__transition_to_device_mode_response__free_unpacked
                     (Logi__Device__Proto__TransitionToDeviceModeResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__transition_to_device_mode_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   logi__device__proto__set_deprovision_request__init
                     (Logi__Device__Proto__SetDeprovisionRequest         *message)
{
  static const Logi__Device__Proto__SetDeprovisionRequest init_value = LOGI__DEVICE__PROTO__SET_DEPROVISION_REQUEST__INIT;
  *message = init_value;
}
size_t logi__device__proto__set_deprovision_request__get_packed_size
                     (const Logi__Device__Proto__SetDeprovisionRequest *message)
{
  assert(message->base.descriptor == &logi__device__proto__set_deprovision_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__set_deprovision_request__pack
                     (const Logi__Device__Proto__SetDeprovisionRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__set_deprovision_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__set_deprovision_request__pack_to_buffer
                     (const Logi__Device__Proto__SetDeprovisionRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__set_deprovision_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__SetDeprovisionRequest *
       logi__device__proto__set_deprovision_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__SetDeprovisionRequest *)
     protobuf_c_message_unpack (&logi__device__proto__set_deprovision_request__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__set_deprovision_request__free_unpacked
                     (Logi__Device__Proto__SetDeprovisionRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__set_deprovision_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   logi__device__proto__set_deprovision_response__init
                     (Logi__Device__Proto__SetDeprovisionResponse         *message)
{
  static const Logi__Device__Proto__SetDeprovisionResponse init_value = LOGI__DEVICE__PROTO__SET_DEPROVISION_RESPONSE__INIT;
  *message = init_value;
}
size_t logi__device__proto__set_deprovision_response__get_packed_size
                     (const Logi__Device__Proto__SetDeprovisionResponse *message)
{
  assert(message->base.descriptor == &logi__device__proto__set_deprovision_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__set_deprovision_response__pack
                     (const Logi__Device__Proto__SetDeprovisionResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__set_deprovision_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__set_deprovision_response__pack_to_buffer
                     (const Logi__Device__Proto__SetDeprovisionResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__set_deprovision_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__SetDeprovisionResponse *
       logi__device__proto__set_deprovision_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__SetDeprovisionResponse *)
     protobuf_c_message_unpack (&logi__device__proto__set_deprovision_response__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__set_deprovision_response__free_unpacked
                     (Logi__Device__Proto__SetDeprovisionResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__set_deprovision_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   logi__device__proto__send_certificate_data_request__init
                     (Logi__Device__Proto__SendCertificateDataRequest         *message)
{
  static const Logi__Device__Proto__SendCertificateDataRequest init_value = LOGI__DEVICE__PROTO__SEND_CERTIFICATE_DATA_REQUEST__INIT;
  *message = init_value;
}
size_t logi__device__proto__send_certificate_data_request__get_packed_size
                     (const Logi__Device__Proto__SendCertificateDataRequest *message)
{
  assert(message->base.descriptor == &logi__device__proto__send_certificate_data_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__send_certificate_data_request__pack
                     (const Logi__Device__Proto__SendCertificateDataRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__send_certificate_data_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__send_certificate_data_request__pack_to_buffer
                     (const Logi__Device__Proto__SendCertificateDataRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__send_certificate_data_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__SendCertificateDataRequest *
       logi__device__proto__send_certificate_data_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__SendCertificateDataRequest *)
     protobuf_c_message_unpack (&logi__device__proto__send_certificate_data_request__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__send_certificate_data_request__free_unpacked
                     (Logi__Device__Proto__SendCertificateDataRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__send_certificate_data_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   logi__device__proto__send_certificate_data_response__init
                     (Logi__Device__Proto__SendCertificateDataResponse         *message)
{
  static const Logi__Device__Proto__SendCertificateDataResponse init_value = LOGI__DEVICE__PROTO__SEND_CERTIFICATE_DATA_RESPONSE__INIT;
  *message = init_value;
}
size_t logi__device__proto__send_certificate_data_response__get_packed_size
                     (const Logi__Device__Proto__SendCertificateDataResponse *message)
{
  assert(message->base.descriptor == &logi__device__proto__send_certificate_data_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__send_certificate_data_response__pack
                     (const Logi__Device__Proto__SendCertificateDataResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__send_certificate_data_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__send_certificate_data_response__pack_to_buffer
                     (const Logi__Device__Proto__SendCertificateDataResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__send_certificate_data_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__SendCertificateDataResponse *
       logi__device__proto__send_certificate_data_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__SendCertificateDataResponse *)
     protobuf_c_message_unpack (&logi__device__proto__send_certificate_data_response__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__send_certificate_data_response__free_unpacked
                     (Logi__Device__Proto__SendCertificateDataResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__send_certificate_data_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCFieldDescriptor logi__device__proto__transition_to_device_mode_request__field_descriptors[2] =
{
  {
    "reserved",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__TransitionToDeviceModeRequest, reserved),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "sender",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__TransitionToDeviceModeRequest, sender),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__transition_to_device_mode_request__field_indices_by_name[] = {
  0,   /* field[0] = reserved */
  1,   /* field[1] = sender */
};
static const ProtobufCIntRange logi__device__proto__transition_to_device_mode_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor logi__device__proto__transition_to_device_mode_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.TransitionToDeviceModeRequest",
  "TransitionToDeviceModeRequest",
  "Logi__Device__Proto__TransitionToDeviceModeRequest",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__TransitionToDeviceModeRequest),
  2,
  logi__device__proto__transition_to_device_mode_request__field_descriptors,
  logi__device__proto__transition_to_device_mode_request__field_indices_by_name,
  1,  logi__device__proto__transition_to_device_mode_request__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__transition_to_device_mode_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor logi__device__proto__transition_to_device_mode_response__field_descriptors[3] =
{
  {
    "success",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__TransitionToDeviceModeResponse, success),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "error",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__TransitionToDeviceModeResponse, error),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "error_description",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__TransitionToDeviceModeResponse, error_description),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__transition_to_device_mode_response__field_indices_by_name[] = {
  1,   /* field[1] = error */
  2,   /* field[2] = error_description */
  0,   /* field[0] = success */
};
static const ProtobufCIntRange logi__device__proto__transition_to_device_mode_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 3 }
};
const ProtobufCMessageDescriptor logi__device__proto__transition_to_device_mode_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.TransitionToDeviceModeResponse",
  "TransitionToDeviceModeResponse",
  "Logi__Device__Proto__TransitionToDeviceModeResponse",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__TransitionToDeviceModeResponse),
  3,
  logi__device__proto__transition_to_device_mode_response__field_descriptors,
  logi__device__proto__transition_to_device_mode_response__field_indices_by_name,
  1,  logi__device__proto__transition_to_device_mode_response__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__transition_to_device_mode_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor logi__device__proto__set_deprovision_request__field_descriptors[1] =
{
  {
    "reserved",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetDeprovisionRequest, reserved),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__set_deprovision_request__field_indices_by_name[] = {
  0,   /* field[0] = reserved */
};
static const ProtobufCIntRange logi__device__proto__set_deprovision_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor logi__device__proto__set_deprovision_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.SetDeprovisionRequest",
  "SetDeprovisionRequest",
  "Logi__Device__Proto__SetDeprovisionRequest",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__SetDeprovisionRequest),
  1,
  logi__device__proto__set_deprovision_request__field_descriptors,
  logi__device__proto__set_deprovision_request__field_indices_by_name,
  1,  logi__device__proto__set_deprovision_request__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__set_deprovision_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor logi__device__proto__set_deprovision_response__field_descriptors[3] =
{
  {
    "success",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetDeprovisionResponse, success),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "error",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetDeprovisionResponse, error),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "error_description",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetDeprovisionResponse, error_description),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__set_deprovision_response__field_indices_by_name[] = {
  1,   /* field[1] = error */
  2,   /* field[2] = error_description */
  0,   /* field[0] = success */
};
static const ProtobufCIntRange logi__device__proto__set_deprovision_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 3 }
};
const ProtobufCMessageDescriptor logi__device__proto__set_deprovision_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.SetDeprovisionResponse",
  "SetDeprovisionResponse",
  "Logi__Device__Proto__SetDeprovisionResponse",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__SetDeprovisionResponse),
  3,
  logi__device__proto__set_deprovision_response__field_descriptors,
  logi__device__proto__set_deprovision_response__field_indices_by_name,
  1,  logi__device__proto__set_deprovision_response__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__set_deprovision_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCEnumValue logi__device__proto__send_certificate_data_request__cert_type__enum_values_by_number[3] =
{
  { "RESERVED", "LOGI__DEVICE__PROTO__SEND_CERTIFICATE_DATA_REQUEST__CERT_TYPE__RESERVED", 0 },
  { "ROOT_CA", "LOGI__DEVICE__PROTO__SEND_CERTIFICATE_DATA_REQUEST__CERT_TYPE__ROOT_CA", 1 },
  { "NET_CONFIG", "LOGI__DEVICE__PROTO__SEND_CERTIFICATE_DATA_REQUEST__CERT_TYPE__NET_CONFIG", 2 },
};
static const ProtobufCIntRange logi__device__proto__send_certificate_data_request__cert_type__value_ranges[] = {
{0, 0},{0, 3}
};
static const ProtobufCEnumValueIndex logi__device__proto__send_certificate_data_request__cert_type__enum_values_by_name[3] =
{
  { "NET_CONFIG", 2 },
  { "RESERVED", 0 },
  { "ROOT_CA", 1 },
};
const ProtobufCEnumDescriptor logi__device__proto__send_certificate_data_request__cert_type__descriptor =
{
  PROTOBUF_C__ENUM_DESCRIPTOR_MAGIC,
  "logi.device.proto.SendCertificateDataRequest.CertType",
  "CertType",
  "Logi__Device__Proto__SendCertificateDataRequest__CertType",
  "logi.device.proto",
  3,
  logi__device__proto__send_certificate_data_request__cert_type__enum_values_by_number,
  3,
  logi__device__proto__send_certificate_data_request__cert_type__enum_values_by_name,
  1,
  logi__device__proto__send_certificate_data_request__cert_type__value_ranges,
  NULL,NULL,NULL,NULL   /* reserved[1234] */
};
static const ProtobufCFieldDescriptor logi__device__proto__send_certificate_data_request__field_descriptors[4] =
{
  {
    "cert_type",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SendCertificateDataRequest, cert_type),
    &logi__device__proto__send_certificate_data_request__cert_type__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "file_name",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SendCertificateDataRequest, file_name),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "cert_data",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BYTES,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SendCertificateDataRequest, cert_data),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "md5",
    4,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SendCertificateDataRequest, md5),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__send_certificate_data_request__field_indices_by_name[] = {
  2,   /* field[2] = cert_data */
  0,   /* field[0] = cert_type */
  1,   /* field[1] = file_name */
  3,   /* field[3] = md5 */
};
static const ProtobufCIntRange logi__device__proto__send_certificate_data_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 4 }
};
const ProtobufCMessageDescriptor logi__device__proto__send_certificate_data_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.SendCertificateDataRequest",
  "SendCertificateDataRequest",
  "Logi__Device__Proto__SendCertificateDataRequest",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__SendCertificateDataRequest),
  4,
  logi__device__proto__send_certificate_data_request__field_descriptors,
  logi__device__proto__send_certificate_data_request__field_indices_by_name,
  1,  logi__device__proto__send_certificate_data_request__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__send_certificate_data_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor logi__device__proto__send_certificate_data_response__field_descriptors[3] =
{
  {
    "success",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SendCertificateDataResponse, success),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "error",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SendCertificateDataResponse, error),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "error_description",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SendCertificateDataResponse, error_description),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__send_certificate_data_response__field_indices_by_name[] = {
  1,   /* field[1] = error */
  2,   /* field[2] = error_description */
  0,   /* field[0] = success */
};
static const ProtobufCIntRange logi__device__proto__send_certificate_data_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 3 }
};
const ProtobufCMessageDescriptor logi__device__proto__send_certificate_data_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.SendCertificateDataResponse",
  "SendCertificateDataResponse",
  "Logi__Device__Proto__SendCertificateDataResponse",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__SendCertificateDataResponse),
  3,
  logi__device__proto__send_certificate_data_response__field_descriptors,
  logi__device__proto__send_certificate_data_response__field_indices_by_name,
  1,  logi__device__proto__send_certificate_data_response__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__send_certificate_data_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
