/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_ANALOGIX_UPDATE_STATUS_INVALID,
    FU_ANALOGIX_UPDATE_STATUS_START,
    FU_ANALOGIX_UPDATE_STATUS_FINISH,
    FU_ANALOGIX_UPDATE_STATUS_ERROR = 0xFF,
} FuAnalogixUpdateStatus;
const gchar *fu_analogix_update_status_to_string(FuAnalogixUpdateStatus val);
