/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_DFU_REQUEST_DETACH,
    FU_DFU_REQUEST_DNLOAD,
    FU_DFU_REQUEST_UPLOAD,
    FU_DFU_REQUEST_GETSTATUS,
    FU_DFU_REQUEST_CLRSTATUS,
    FU_DFU_REQUEST_GETSTATE,
    FU_DFU_REQUEST_ABORT,
} FuDfuRequest;
typedef enum {
    FU_DFU_STATUS_OK,
    FU_DFU_STATUS_ERR_TARGET,
    FU_DFU_STATUS_ERR_FILE,
    FU_DFU_STATUS_ERR_WRITE,
    FU_DFU_STATUS_ERR_ERASE,
    FU_DFU_STATUS_ERR_CHECK_ERASED,
    FU_DFU_STATUS_ERR_PROG,
    FU_DFU_STATUS_ERR_VERIFY,
    FU_DFU_STATUS_ERR_ADDRESS,
    FU_DFU_STATUS_ERR_NOTDONE,
    FU_DFU_STATUS_ERR_FIRMWARE,
    FU_DFU_STATUS_ERR_VENDOR,
    FU_DFU_STATUS_ERR_USBR,
    FU_DFU_STATUS_ERR_POR,
    FU_DFU_STATUS_ERR_UNKNOWN,
    FU_DFU_STATUS_ERR_STALLDPKT,
} FuDfuStatus;
const gchar *fu_dfu_status_to_string(FuDfuStatus val);
typedef enum {
    FU_DFU_STATE_APP_IDLE,
    FU_DFU_STATE_APP_DETACH,
    FU_DFU_STATE_DFU_IDLE,
    FU_DFU_STATE_DFU_DNLOAD_SYNC,
    FU_DFU_STATE_DFU_DNBUSY,
    FU_DFU_STATE_DFU_DNLOAD_IDLE,
    FU_DFU_STATE_DFU_MANIFEST_SYNC,
    FU_DFU_STATE_DFU_MANIFEST,
    FU_DFU_STATE_DFU_MANIFEST_WAIT_RESET,
    FU_DFU_STATE_DFU_UPLOAD_IDLE,
    FU_DFU_STATE_DFU_ERROR,
} FuDfuState;
const gchar *fu_dfu_state_to_string(FuDfuState val);
typedef enum {
    FU_DFU_SECTOR_CAP_NONE = 0,
    FU_DFU_SECTOR_CAP_READABLE = 1<<0,
    FU_DFU_SECTOR_CAP_WRITEABLE = 1<<1,
    FU_DFU_SECTOR_CAP_ERASABLE = 1<<2,
} FuDfuSectorCap;
gchar *fu_dfu_sector_cap_to_string(FuDfuSectorCap val);
