/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_LINUX_LOCKDOWN_UNKNOWN,
    FU_LINUX_LOCKDOWN_INVALID,
    FU_LINUX_LOCKDOWN_NONE,
    FU_LINUX_LOCKDOWN_INTEGRITY,
    FU_LINUX_LOCKDOWN_CONFIDENTIALITY,
} FuLinuxLockdown;
const gchar *fu_linux_lockdown_to_string(FuLinuxLockdown val);
