/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_DAEMON_MACHINE_KIND_UNKNOWN,
    FU_DAEMON_MACHINE_KIND_PHYSICAL,
    FU_DAEMON_MACHINE_KIND_VIRTUAL,
    FU_DAEMON_MACHINE_KIND_CONTAINER,
} FuDaemonMachineKind;
FuDaemonMachineKind fu_daemon_machine_kind_from_string(const gchar *val);
