/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_SCSI_SENSE_KEY_NO_SENSE = 0x00,
    FU_SCSI_SENSE_KEY_RECOVERED_ERROR = 0x01,
    FU_SCSI_SENSE_KEY_NOT_READY = 0x02,
    FU_SCSI_SENSE_KEY_MEDIUM_ERROR = 0x03,
    FU_SCSI_SENSE_KEY_HARDWARE_ERROR = 0x04,
    FU_SCSI_SENSE_KEY_ILLEGAL_REQUEST = 0x05,
    FU_SCSI_SENSE_KEY_UNIT_ATTENTION = 0x06,
    FU_SCSI_SENSE_KEY_DATA_PROTECT = 0x07,
    FU_SCSI_SENSE_KEY_BLANK_CHECK = 0x08,
    FU_SCSI_SENSE_KEY_VENDOR_SPECIFIC = 0x09,
    FU_SCSI_SENSE_KEY_COPY_ABORTED = 0x0A,
    FU_SCSI_SENSE_KEY_ABORTED_COMMAND = 0x0B,
    FU_SCSI_SENSE_KEY_EQUAL = 0x0C,
    FU_SCSI_SENSE_KEY_VOLUME_OVERFLOW = 0x0D,
    FU_SCSI_SENSE_KEY_MISCOMPARE = 0x0E,
} FuScsiSenseKey;
const gchar *fu_scsi_sense_key_to_string(FuScsiSenseKey val);
