/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: rightsight.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "rightsight.pb-c.h"
void   logi__device__proto__right_sight_configuration__init
                     (Logi__Device__Proto__RightSightConfiguration         *message)
{
  static const Logi__Device__Proto__RightSightConfiguration init_value = LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__INIT;
  *message = init_value;
}
size_t logi__device__proto__right_sight_configuration__get_packed_size
                     (const Logi__Device__Proto__RightSightConfiguration *message)
{
  assert(message->base.descriptor == &logi__device__proto__right_sight_configuration__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__right_sight_configuration__pack
                     (const Logi__Device__Proto__RightSightConfiguration *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__right_sight_configuration__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__right_sight_configuration__pack_to_buffer
                     (const Logi__Device__Proto__RightSightConfiguration *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__right_sight_configuration__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__RightSightConfiguration *
       logi__device__proto__right_sight_configuration__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__RightSightConfiguration *)
     protobuf_c_message_unpack (&logi__device__proto__right_sight_configuration__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__right_sight_configuration__free_unpacked
                     (Logi__Device__Proto__RightSightConfiguration *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__right_sight_configuration__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   logi__device__proto__set_right_sight_configuration_request__init
                     (Logi__Device__Proto__SetRightSightConfigurationRequest         *message)
{
  static const Logi__Device__Proto__SetRightSightConfigurationRequest init_value = LOGI__DEVICE__PROTO__SET_RIGHT_SIGHT_CONFIGURATION_REQUEST__INIT;
  *message = init_value;
}
size_t logi__device__proto__set_right_sight_configuration_request__get_packed_size
                     (const Logi__Device__Proto__SetRightSightConfigurationRequest *message)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__set_right_sight_configuration_request__pack
                     (const Logi__Device__Proto__SetRightSightConfigurationRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__set_right_sight_configuration_request__pack_to_buffer
                     (const Logi__Device__Proto__SetRightSightConfigurationRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__SetRightSightConfigurationRequest *
       logi__device__proto__set_right_sight_configuration_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__SetRightSightConfigurationRequest *)
     protobuf_c_message_unpack (&logi__device__proto__set_right_sight_configuration_request__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__set_right_sight_configuration_request__free_unpacked
                     (Logi__Device__Proto__SetRightSightConfigurationRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   logi__device__proto__set_right_sight_configuration_response__init
                     (Logi__Device__Proto__SetRightSightConfigurationResponse         *message)
{
  static const Logi__Device__Proto__SetRightSightConfigurationResponse init_value = LOGI__DEVICE__PROTO__SET_RIGHT_SIGHT_CONFIGURATION_RESPONSE__INIT;
  *message = init_value;
}
size_t logi__device__proto__set_right_sight_configuration_response__get_packed_size
                     (const Logi__Device__Proto__SetRightSightConfigurationResponse *message)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__set_right_sight_configuration_response__pack
                     (const Logi__Device__Proto__SetRightSightConfigurationResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__set_right_sight_configuration_response__pack_to_buffer
                     (const Logi__Device__Proto__SetRightSightConfigurationResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__SetRightSightConfigurationResponse *
       logi__device__proto__set_right_sight_configuration_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__SetRightSightConfigurationResponse *)
     protobuf_c_message_unpack (&logi__device__proto__set_right_sight_configuration_response__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__set_right_sight_configuration_response__free_unpacked
                     (Logi__Device__Proto__SetRightSightConfigurationResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   logi__device__proto__set_right_sight_configuration_requestv2__init
                     (Logi__Device__Proto__SetRightSightConfigurationRequestv2         *message)
{
  static const Logi__Device__Proto__SetRightSightConfigurationRequestv2 init_value = LOGI__DEVICE__PROTO__SET_RIGHT_SIGHT_CONFIGURATION_REQUESTV2__INIT;
  *message = init_value;
}
size_t logi__device__proto__set_right_sight_configuration_requestv2__get_packed_size
                     (const Logi__Device__Proto__SetRightSightConfigurationRequestv2 *message)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_requestv2__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t logi__device__proto__set_right_sight_configuration_requestv2__pack
                     (const Logi__Device__Proto__SetRightSightConfigurationRequestv2 *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_requestv2__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t logi__device__proto__set_right_sight_configuration_requestv2__pack_to_buffer
                     (const Logi__Device__Proto__SetRightSightConfigurationRequestv2 *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_requestv2__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Logi__Device__Proto__SetRightSightConfigurationRequestv2 *
       logi__device__proto__set_right_sight_configuration_requestv2__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Logi__Device__Proto__SetRightSightConfigurationRequestv2 *)
     protobuf_c_message_unpack (&logi__device__proto__set_right_sight_configuration_requestv2__descriptor,
                                allocator, len, data);
}
void   logi__device__proto__set_right_sight_configuration_requestv2__free_unpacked
                     (Logi__Device__Proto__SetRightSightConfigurationRequestv2 *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &logi__device__proto__set_right_sight_configuration_requestv2__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCEnumValue logi__device__proto__right_sight_configuration__speaker_tracking_mode__enum_values_by_number[3] =
{
  { "GROUP_VIEW", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__SPEAKER_TRACKING_MODE__GROUP_VIEW", 0 },
  { "SPEAKER_VIEW", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__SPEAKER_TRACKING_MODE__SPEAKER_VIEW", 1 },
  { "GRID_VIEW", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__SPEAKER_TRACKING_MODE__GRID_VIEW", 2 },
};
static const ProtobufCIntRange logi__device__proto__right_sight_configuration__speaker_tracking_mode__value_ranges[] = {
{0, 0},{0, 3}
};
static const ProtobufCEnumValueIndex logi__device__proto__right_sight_configuration__speaker_tracking_mode__enum_values_by_name[3] =
{
  { "GRID_VIEW", 2 },
  { "GROUP_VIEW", 0 },
  { "SPEAKER_VIEW", 1 },
};
const ProtobufCEnumDescriptor logi__device__proto__right_sight_configuration__speaker_tracking_mode__descriptor =
{
  PROTOBUF_C__ENUM_DESCRIPTOR_MAGIC,
  "logi.device.proto.RightSightConfiguration.SpeakerTrackingMode",
  "SpeakerTrackingMode",
  "Logi__Device__Proto__RightSightConfiguration__SpeakerTrackingMode",
  "logi.device.proto",
  3,
  logi__device__proto__right_sight_configuration__speaker_tracking_mode__enum_values_by_number,
  3,
  logi__device__proto__right_sight_configuration__speaker_tracking_mode__enum_values_by_name,
  1,
  logi__device__proto__right_sight_configuration__speaker_tracking_mode__value_ranges,
  NULL,NULL,NULL,NULL   /* reserved[1234] */
};
static const ProtobufCEnumValue logi__device__proto__right_sight_configuration__speaker_detection_speed__enum_values_by_number[3] =
{
  { "SLOW_SPEAKER_SPEED", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__SPEAKER_DETECTION_SPEED__SLOW_SPEAKER_SPEED", 0 },
  { "DEFAULT_SPEAKER_SPEED", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__SPEAKER_DETECTION_SPEED__DEFAULT_SPEAKER_SPEED", 1 },
  { "FAST_SPEAKER_SPEED", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__SPEAKER_DETECTION_SPEED__FAST_SPEAKER_SPEED", 2 },
};
static const ProtobufCIntRange logi__device__proto__right_sight_configuration__speaker_detection_speed__value_ranges[] = {
{0, 0},{0, 3}
};
static const ProtobufCEnumValueIndex logi__device__proto__right_sight_configuration__speaker_detection_speed__enum_values_by_name[3] =
{
  { "DEFAULT_SPEAKER_SPEED", 1 },
  { "FAST_SPEAKER_SPEED", 2 },
  { "SLOW_SPEAKER_SPEED", 0 },
};
const ProtobufCEnumDescriptor logi__device__proto__right_sight_configuration__speaker_detection_speed__descriptor =
{
  PROTOBUF_C__ENUM_DESCRIPTOR_MAGIC,
  "logi.device.proto.RightSightConfiguration.SpeakerDetectionSpeed",
  "SpeakerDetectionSpeed",
  "Logi__Device__Proto__RightSightConfiguration__SpeakerDetectionSpeed",
  "logi.device.proto",
  3,
  logi__device__proto__right_sight_configuration__speaker_detection_speed__enum_values_by_number,
  3,
  logi__device__proto__right_sight_configuration__speaker_detection_speed__enum_values_by_name,
  1,
  logi__device__proto__right_sight_configuration__speaker_detection_speed__value_ranges,
  NULL,NULL,NULL,NULL   /* reserved[1234] */
};
static const ProtobufCEnumValue logi__device__proto__right_sight_configuration__framing_speed__enum_values_by_number[3] =
{
  { "SLOW_FRAME_SPEED", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__FRAMING_SPEED__SLOW_FRAME_SPEED", 0 },
  { "DEFAULT_FRAME_SPEED", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__FRAMING_SPEED__DEFAULT_FRAME_SPEED", 1 },
  { "FAST_FRAME_SPEED", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__FRAMING_SPEED__FAST_FRAME_SPEED", 2 },
};
static const ProtobufCIntRange logi__device__proto__right_sight_configuration__framing_speed__value_ranges[] = {
{0, 0},{0, 3}
};
static const ProtobufCEnumValueIndex logi__device__proto__right_sight_configuration__framing_speed__enum_values_by_name[3] =
{
  { "DEFAULT_FRAME_SPEED", 1 },
  { "FAST_FRAME_SPEED", 2 },
  { "SLOW_FRAME_SPEED", 0 },
};
const ProtobufCEnumDescriptor logi__device__proto__right_sight_configuration__framing_speed__descriptor =
{
  PROTOBUF_C__ENUM_DESCRIPTOR_MAGIC,
  "logi.device.proto.RightSightConfiguration.FramingSpeed",
  "FramingSpeed",
  "Logi__Device__Proto__RightSightConfiguration__FramingSpeed",
  "logi.device.proto",
  3,
  logi__device__proto__right_sight_configuration__framing_speed__enum_values_by_number,
  3,
  logi__device__proto__right_sight_configuration__framing_speed__enum_values_by_name,
  1,
  logi__device__proto__right_sight_configuration__framing_speed__value_ranges,
  NULL,NULL,NULL,NULL   /* reserved[1234] */
};
static const ProtobufCEnumValue logi__device__proto__right_sight_configuration__mode__enum_values_by_number[3] =
{
  { "DO_NOT_USE", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__MODE__DO_NOT_USE", 0 },
  { "DYNAMIC", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__MODE__DYNAMIC", 1 },
  { "ON_CALL_START", "LOGI__DEVICE__PROTO__RIGHT_SIGHT_CONFIGURATION__MODE__ON_CALL_START", 2 },
};
static const ProtobufCIntRange logi__device__proto__right_sight_configuration__mode__value_ranges[] = {
{0, 0},{0, 3}
};
static const ProtobufCEnumValueIndex logi__device__proto__right_sight_configuration__mode__enum_values_by_name[3] =
{
  { "DO_NOT_USE", 0 },
  { "DYNAMIC", 1 },
  { "ON_CALL_START", 2 },
};
const ProtobufCEnumDescriptor logi__device__proto__right_sight_configuration__mode__descriptor =
{
  PROTOBUF_C__ENUM_DESCRIPTOR_MAGIC,
  "logi.device.proto.RightSightConfiguration.Mode",
  "Mode",
  "Logi__Device__Proto__RightSightConfiguration__Mode",
  "logi.device.proto",
  3,
  logi__device__proto__right_sight_configuration__mode__enum_values_by_number,
  3,
  logi__device__proto__right_sight_configuration__mode__enum_values_by_name,
  1,
  logi__device__proto__right_sight_configuration__mode__value_ranges,
  NULL,NULL,NULL,NULL   /* reserved[1234] */
};
static const ProtobufCFieldDescriptor logi__device__proto__right_sight_configuration__field_descriptors[12] =
{
  {
    "enabled",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, enabled),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "mode",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, mode),
    &logi__device__proto__right_sight_configuration__mode__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "last_modified",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_UINT64,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, last_modified),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "trackingMode",
    4,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, trackingmode),
    &logi__device__proto__right_sight_configuration__speaker_tracking_mode__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "pip",
    5,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, pip),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "reduceTransitions",
    6,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, reducetransitions),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "speakerDetectionSpeed",
    7,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, speakerdetectionspeed),
    &logi__device__proto__right_sight_configuration__speaker_detection_speed__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "framingSpeed",
    8,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, framingspeed),
    &logi__device__proto__right_sight_configuration__framing_speed__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "groupFramingSpeed",
    9,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, groupframingspeed),
    &logi__device__proto__right_sight_configuration__framing_speed__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "speakerFramingSpeed",
    10,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, speakerframingspeed),
    &logi__device__proto__right_sight_configuration__framing_speed__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "useSight",
    11,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, usesight),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "smartSwitching",
    12,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__RightSightConfiguration, smartswitching),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__right_sight_configuration__field_indices_by_name[] = {
  0,   /* field[0] = enabled */
  7,   /* field[7] = framingSpeed */
  8,   /* field[8] = groupFramingSpeed */
  2,   /* field[2] = last_modified */
  1,   /* field[1] = mode */
  4,   /* field[4] = pip */
  5,   /* field[5] = reduceTransitions */
  11,   /* field[11] = smartSwitching */
  6,   /* field[6] = speakerDetectionSpeed */
  9,   /* field[9] = speakerFramingSpeed */
  3,   /* field[3] = trackingMode */
  10,   /* field[10] = useSight */
};
static const ProtobufCIntRange logi__device__proto__right_sight_configuration__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 12 }
};
const ProtobufCMessageDescriptor logi__device__proto__right_sight_configuration__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.RightSightConfiguration",
  "RightSightConfiguration",
  "Logi__Device__Proto__RightSightConfiguration",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__RightSightConfiguration),
  12,
  logi__device__proto__right_sight_configuration__field_descriptors,
  logi__device__proto__right_sight_configuration__field_indices_by_name,
  1,  logi__device__proto__right_sight_configuration__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__right_sight_configuration__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor logi__device__proto__set_right_sight_configuration_request__field_descriptors[2] =
{
  {
    "enabled",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequest, enabled),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "mode",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequest, mode),
    &logi__device__proto__right_sight_configuration__mode__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__set_right_sight_configuration_request__field_indices_by_name[] = {
  0,   /* field[0] = enabled */
  1,   /* field[1] = mode */
};
static const ProtobufCIntRange logi__device__proto__set_right_sight_configuration_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor logi__device__proto__set_right_sight_configuration_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.SetRightSightConfigurationRequest",
  "SetRightSightConfigurationRequest",
  "Logi__Device__Proto__SetRightSightConfigurationRequest",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__SetRightSightConfigurationRequest),
  2,
  logi__device__proto__set_right_sight_configuration_request__field_descriptors,
  logi__device__proto__set_right_sight_configuration_request__field_indices_by_name,
  1,  logi__device__proto__set_right_sight_configuration_request__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__set_right_sight_configuration_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor logi__device__proto__set_right_sight_configuration_response__field_descriptors[2] =
{
  {
    "errors",
    1,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(Logi__Device__Proto__SetRightSightConfigurationResponse, n_errors),
    offsetof(Logi__Device__Proto__SetRightSightConfigurationResponse, errors),
    &logi__device__proto__error__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "right_sight_configuration",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationResponse, right_sight_configuration),
    &logi__device__proto__right_sight_configuration__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__set_right_sight_configuration_response__field_indices_by_name[] = {
  0,   /* field[0] = errors */
  1,   /* field[1] = right_sight_configuration */
};
static const ProtobufCIntRange logi__device__proto__set_right_sight_configuration_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor logi__device__proto__set_right_sight_configuration_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.SetRightSightConfigurationResponse",
  "SetRightSightConfigurationResponse",
  "Logi__Device__Proto__SetRightSightConfigurationResponse",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__SetRightSightConfigurationResponse),
  2,
  logi__device__proto__set_right_sight_configuration_response__field_descriptors,
  logi__device__proto__set_right_sight_configuration_response__field_indices_by_name,
  1,  logi__device__proto__set_right_sight_configuration_response__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__set_right_sight_configuration_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor logi__device__proto__set_right_sight_configuration_requestv2__field_descriptors[10] =
{
  {
    "enabled",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, enabled),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "trackingMode",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, trackingmode),
    &logi__device__proto__right_sight_configuration__speaker_tracking_mode__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "mode",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, mode),
    &logi__device__proto__right_sight_configuration__mode__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "pip",
    4,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, pip),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "speakerDetectionSpeed",
    5,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, speakerdetectionspeed),
    &logi__device__proto__right_sight_configuration__speaker_detection_speed__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "framingSpeed",
    6,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, framingspeed),
    &logi__device__proto__right_sight_configuration__framing_speed__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "groupFramingSpeed",
    8,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, groupframingspeed),
    &logi__device__proto__right_sight_configuration__framing_speed__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "speakerFramingSpeed",
    9,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_ENUM,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, speakerframingspeed),
    &logi__device__proto__right_sight_configuration__framing_speed__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "useSight",
    10,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, usesight),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "smartSwitching",
    11,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT32,
    0,   /* quantifier_offset */
    offsetof(Logi__Device__Proto__SetRightSightConfigurationRequestv2, smartswitching),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned logi__device__proto__set_right_sight_configuration_requestv2__field_indices_by_name[] = {
  0,   /* field[0] = enabled */
  5,   /* field[5] = framingSpeed */
  6,   /* field[6] = groupFramingSpeed */
  2,   /* field[2] = mode */
  3,   /* field[3] = pip */
  9,   /* field[9] = smartSwitching */
  4,   /* field[4] = speakerDetectionSpeed */
  7,   /* field[7] = speakerFramingSpeed */
  1,   /* field[1] = trackingMode */
  8,   /* field[8] = useSight */
};
static const ProtobufCIntRange logi__device__proto__set_right_sight_configuration_requestv2__number_ranges[2 + 1] =
{
  { 1, 0 },
  { 8, 6 },
  { 0, 10 }
};
const ProtobufCMessageDescriptor logi__device__proto__set_right_sight_configuration_requestv2__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "logi.device.proto.SetRightSightConfigurationRequestv2",
  "SetRightSightConfigurationRequestv2",
  "Logi__Device__Proto__SetRightSightConfigurationRequestv2",
  "logi.device.proto",
  sizeof(Logi__Device__Proto__SetRightSightConfigurationRequestv2),
  10,
  logi__device__proto__set_right_sight_configuration_requestv2__field_descriptors,
  logi__device__proto__set_right_sight_configuration_requestv2__field_indices_by_name,
  2,  logi__device__proto__set_right_sight_configuration_requestv2__number_ranges,
  (ProtobufCMessageInit) logi__device__proto__set_right_sight_configuration_requestv2__init,
  NULL,NULL,NULL    /* reserved[123] */
};
