/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: device_common.proto */

#ifndef PROTOBUF_C_device_5fcommon_2eproto__INCLUDED
#define PROTOBUF_C_device_5fcommon_2eproto__INCLUDED

#include <protobuf-c/protobuf-c.h>

PROTOBUF_C__BEGIN_DECLS

#if PROTOBUF_C_VERSION_NUMBER < 1003000
# error This file was generated by a newer version of protoc-c which is incompatible with your libprotobuf-c headers. Please update your headers.
#elif 1005000 < PROTOBUF_C_MIN_COMPILER_VERSION
# error This file was generated by an older version of protoc-c which is incompatible with your libprotobuf-c headers. Please regenerate this file with a newer version of protoc-c.
#endif


typedef struct Logi__Device__Proto__Error Logi__Device__Proto__Error;


/* --- enums --- */


/* --- messages --- */

/*
 **
 * This error messages describe a failure that was encountered
 * by the Sync service and primarily consist of an error code
 * and a short, human-readable message. Therefore, if a client
 * receives a message with a field reserved for Error messages,
 * it is prudent that the application first check if there are
 * errors before doing any further processing of the message.
 */
struct  Logi__Device__Proto__Error
{
  ProtobufCMessage base;
  /*
   **
   * (REQUIRED) Error code.
   */
  uint32_t error_code;
  /*
   **
   * (OPTIONAL) Short, human-readable error message. If no
   * message is available, then this will be an empty string.
   */
  char *error_message;
  /*
   **
   * (OPTIONAL) A URI to a log file or some other document
   * that contains more detailed information about the error.
   * If such a file is not available, this will be an empty
   * string.
   */
  char *error_log_uri;
  /*
   **
   * (OPTIONAL) An optional JSON string with additional
   * metadata that may be useful to the client.
   */
  char *json_metadata;
};
#define LOGI__DEVICE__PROTO__ERROR__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&logi__device__proto__error__descriptor) \
, 0, (char *)protobuf_c_empty_string, (char *)protobuf_c_empty_string, (char *)protobuf_c_empty_string }


/* Logi__Device__Proto__Error methods */
void   logi__device__proto__error__init
                     (Logi__Device__Proto__Error         *message);
size_t logi__device__proto__error__get_packed_size
                     (const Logi__Device__Proto__Error   *message);
size_t logi__device__proto__error__pack
                     (const Logi__Device__Proto__Error   *message,
                      uint8_t             *out);
size_t logi__device__proto__error__pack_to_buffer
                     (const Logi__Device__Proto__Error   *message,
                      ProtobufCBuffer     *buffer);
Logi__Device__Proto__Error *
       logi__device__proto__error__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   logi__device__proto__error__free_unpacked
                     (Logi__Device__Proto__Error *message,
                      ProtobufCAllocator *allocator);
/* --- per-message closures --- */

typedef void (*Logi__Device__Proto__Error_Closure)
                 (const Logi__Device__Proto__Error *message,
                  void *closure_data);

/* --- services --- */


/* --- descriptors --- */

extern const ProtobufCMessageDescriptor logi__device__proto__error__descriptor;

PROTOBUF_C__END_DECLS


#endif  /* PROTOBUF_C_device_5fcommon_2eproto__INCLUDED */
