#include "./plugins/acpi-phat/fu-acpi-phat-plugin.h"
#include "./plugins/algoltek-usb/fu-algoltek-usb-plugin.h"
#include "./plugins/analogix/fu-analogix-plugin.h"
#include "./plugins/android-boot/fu-android-boot-plugin.h"
#include "./plugins/ata/fu-ata-plugin.h"
#include "./plugins/audio-s5gen2/fu-audio-s5gen2-plugin.h"
#include "./plugins/aver-hid/fu-aver-hid-plugin.h"
#include "./plugins/bcm57xx/fu-bcm57xx-plugin.h"
#include "./plugins/ccgx/fu-ccgx-plugin.h"
#include "./plugins/ccgx-dmc/fu-ccgx-dmc-plugin.h"
#include "./plugins/cfu/fu-cfu-plugin.h"
#include "./plugins/ch341a/fu-ch341a-plugin.h"
#include "./plugins/ch347/fu-ch347-plugin.h"
#include "./plugins/colorhug/fu-colorhug-plugin.h"
#include "./plugins/corsair/fu-corsair-plugin.h"
#include "./plugins/cpu/fu-cpu-plugin.h"
#include "./plugins/cros-ec/fu-cros-ec-plugin.h"
#include "./plugins/dell-dock/fu-dell-dock-plugin.h"
#include "./plugins/dfu/fu-dfu-plugin.h"
#include "./plugins/dfu-csr/fu-dfu-csr-plugin.h"
#include "./plugins/ebitdo/fu-ebitdo-plugin.h"
#include "./plugins/elantp/fu-elantp-plugin.h"
#include "./plugins/elanfp/fu-elanfp-plugin.h"
#include "./plugins/emmc/fu-emmc-plugin.h"
#include "./plugins/ep963x/fu-ep963x-plugin.h"
#include "./plugins/fastboot/fu-fastboot-plugin.h"
#include "./plugins/focalfp/fu-focalfp-plugin.h"
#include "./plugins/fpc/fu-fpc-plugin.h"
#include "./plugins/fresco-pd/fu-fresco-pd-plugin.h"
#include "./plugins/genesys/fu-genesys-plugin.h"
#include "./plugins/genesys-gl32xx/fu-genesys-gl32xx-plugin.h"
#include "./plugins/goodix-moc/fu-goodixmoc-plugin.h"
#include "./plugins/goodix-tp/fu-goodixtp-plugin.h"
#include "./plugins/gpio/fu-gpio-plugin.h"
#include "./plugins/hailuck/fu-hailuck-plugin.h"
#include "./plugins/intel-gsc/fu-igsc-plugin.h"
#include "./plugins/intel-usb4/fu-intel-usb4-plugin.h"
#include "./plugins/jabra/fu-jabra-plugin.h"
#include "./plugins/jabra-gnp/fu-jabra-gnp-plugin.h"
#include "./plugins/kinetic-dp/fu-kinetic-dp-plugin.h"
#include "./plugins/linux-display/fu-linux-display-plugin.h"
#include "./plugins/linux-lockdown/fu-linux-lockdown-plugin.h"
#include "./plugins/linux-swap/fu-linux-swap-plugin.h"
#include "./plugins/linux-tainted/fu-linux-tainted-plugin.h"
#include "./plugins/logind/fu-logind-plugin.h"
#include "./plugins/logitech-hidpp/fu-logitech-hidpp-plugin.h"
#include "./plugins/logitech-bulkcontroller/fu-logitech-bulkcontroller-plugin.h"
#include "./plugins/logitech-rallysystem/fu-logitech-rallysystem-plugin.h"
#include "./plugins/logitech-scribe/fu-logitech-scribe-plugin.h"
#include "./plugins/logitech-tap/fu-logitech-tap-plugin.h"
#include "./plugins/mediatek-scaler/fu-mediatek-scaler-plugin.h"
#include "./plugins/mtd/fu-mtd-plugin.h"
#include "./plugins/nitrokey/fu-nitrokey-plugin.h"
#include "./plugins/nordic-hid/fu-nordic-hid-plugin.h"
#include "./plugins/nvme/fu-nvme-plugin.h"
#include "./plugins/optionrom/fu-optionrom-plugin.h"
#include "./plugins/parade-lspcon/fu-parade-lspcon-plugin.h"
#include "./plugins/pci-bcr/fu-pci-bcr-plugin.h"
#include "./plugins/pci-mei/fu-pci-mei-plugin.h"
#include "./plugins/pixart-rf/fu-pxi-plugin.h"
#include "./plugins/qsi-dock/fu-qsi-dock-plugin.h"
#include "./plugins/realtek-mst/fu-realtek-mst-plugin.h"
#include "./plugins/redfish/fu-redfish-plugin.h"
#include "./plugins/rts54hid/fu-rts54hid-plugin.h"
#include "./plugins/rts54hub/fu-rts54hub-plugin.h"
#include "./plugins/steelseries/fu-steelseries-plugin.h"
#include "./plugins/scsi/fu-scsi-plugin.h"
#include "./plugins/superio/fu-superio-plugin.h"
#include "./plugins/synaptics-cape/fu-synaptics-cape-plugin.h"
#include "./plugins/synaptics-cxaudio/fu-synaptics-cxaudio-plugin.h"
#include "./plugins/synaptics-mst/fu-synaptics-mst-plugin.h"
#include "./plugins/synaptics-prometheus/fu-synaprom-plugin.h"
#include "./plugins/synaptics-rmi/fu-synaptics-rmi-plugin.h"
#include "./plugins/system76-launch/fu-system76-launch-plugin.h"
#include "./plugins/test/fu-test-plugin.h"
#include "./plugins/test/fu-test-ble-plugin.h"
#include "./plugins/thelio-io/fu-thelio-io-plugin.h"
#include "./plugins/ti-tps6598x/fu-ti-tps6598x-plugin.h"
#include "./plugins/uefi-dbx/fu-uefi-dbx-plugin.h"
#include "./plugins/uf2/fu-uf2-plugin.h"
#include "./plugins/upower/fu-upower-plugin.h"
#include "./plugins/usi-dock/fu-usi-dock-plugin.h"
#include "./plugins/vbe/fu-vbe-plugin.h"
#include "./plugins/vli/fu-vli-plugin.h"
#include "./plugins/wacom-raw/fu-wacom-raw-plugin.h"
#include "./plugins/wacom-usb/fu-wac-plugin.h"
#include "./plugins/wistron-dock/fu-wistron-dock-plugin.h"
GType (*fu_plugin_externals[])(void) = { fu_acpi_phat_plugin_get_type, fu_algoltek_usb_plugin_get_type, fu_analogix_plugin_get_type, fu_android_boot_plugin_get_type, fu_ata_plugin_get_type, fu_audio_s5gen2_plugin_get_type, fu_aver_hid_plugin_get_type, fu_bcm57xx_plugin_get_type, fu_ccgx_plugin_get_type, fu_ccgx_dmc_plugin_get_type, fu_cfu_plugin_get_type, fu_ch341a_plugin_get_type, fu_ch347_plugin_get_type, fu_colorhug_plugin_get_type, fu_corsair_plugin_get_type, fu_cpu_plugin_get_type, fu_cros_ec_plugin_get_type, fu_dell_dock_plugin_get_type, fu_dfu_plugin_get_type, fu_dfu_csr_plugin_get_type, fu_ebitdo_plugin_get_type, fu_elantp_plugin_get_type, fu_elanfp_plugin_get_type, fu_emmc_plugin_get_type, fu_ep963x_plugin_get_type, fu_fastboot_plugin_get_type, fu_focalfp_plugin_get_type, fu_fpc_plugin_get_type, fu_fresco_pd_plugin_get_type, fu_genesys_plugin_get_type, fu_genesys_gl32xx_plugin_get_type, fu_goodixmoc_plugin_get_type, fu_goodixtp_plugin_get_type, fu_gpio_plugin_get_type, fu_hailuck_plugin_get_type, fu_igsc_plugin_get_type, fu_intel_usb4_plugin_get_type, fu_jabra_plugin_get_type, fu_jabra_gnp_plugin_get_type, fu_kinetic_dp_plugin_get_type, fu_linux_display_plugin_get_type, fu_linux_lockdown_plugin_get_type, fu_linux_swap_plugin_get_type, fu_linux_tainted_plugin_get_type, fu_logind_plugin_get_type, fu_logitech_hidpp_plugin_get_type, fu_logitech_bulkcontroller_plugin_get_type, fu_logitech_rallysystem_plugin_get_type, fu_logitech_scribe_plugin_get_type, fu_logitech_tap_plugin_get_type, fu_mediatek_scaler_plugin_get_type, fu_mtd_plugin_get_type, fu_nitrokey_plugin_get_type, fu_nordic_hid_plugin_get_type, fu_nvme_plugin_get_type, fu_optionrom_plugin_get_type, fu_parade_lspcon_plugin_get_type, fu_pci_bcr_plugin_get_type, fu_pci_mei_plugin_get_type, fu_pxi_plugin_get_type, fu_qsi_dock_plugin_get_type, fu_realtek_mst_plugin_get_type, fu_redfish_plugin_get_type, fu_rts54hid_plugin_get_type, fu_rts54hub_plugin_get_type, fu_steelseries_plugin_get_type, fu_scsi_plugin_get_type, fu_superio_plugin_get_type, fu_synaptics_cape_plugin_get_type, fu_synaptics_cxaudio_plugin_get_type, fu_synaptics_mst_plugin_get_type, fu_synaprom_plugin_get_type, fu_synaptics_rmi_plugin_get_type, fu_system76_launch_plugin_get_type, fu_test_plugin_get_type, fu_test_ble_plugin_get_type, fu_thelio_io_plugin_get_type, fu_ti_tps6598x_plugin_get_type, fu_uefi_dbx_plugin_get_type, fu_uf2_plugin_get_type, fu_upower_plugin_get_type, fu_usi_dock_plugin_get_type, fu_vbe_plugin_get_type, fu_vli_plugin_get_type, fu_wacom_raw_plugin_get_type, fu_wac_plugin_get_type, fu_wistron_dock_plugin_get_type, NULL };
