/* auto-generated, do not modify */
#include "config.h"

#include "fu-ep963x-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_ep963x_smbus_error_to_string(FuEp963xSmbusError val)
{
    if (val == FU_EP963X_SMBUS_ERROR_NONE)
        return "none";
    if (val == FU_EP963X_SMBUS_ERROR_ADDRESS)
        return "address";
    if (val == FU_EP963X_SMBUS_ERROR_NO_ACK)
        return "no-ack";
    if (val == FU_EP963X_SMBUS_ERROR_ARBITRATION)
        return "arbitration";
    if (val == FU_EP963X_SMBUS_ERROR_COMMAND)
        return "command";
    if (val == FU_EP963X_SMBUS_ERROR_TIMEOUT)
        return "timeout";
    if (val == FU_EP963X_SMBUS_ERROR_BUSY)
        return "busy";
    return NULL;
}
