/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_HAILUCK_CMD_ERASE = 0x45,
    FU_HAILUCK_CMD_READ_BLOCK_START = 0x52,
    FU_HAILUCK_CMD_ATTACH = 0x55,
    FU_HAILUCK_CMD_WRITE_BLOCK_START = 0x57,
    FU_HAILUCK_CMD_READ_BLOCK = 0x72,
    FU_HAILUCK_CMD_DETACH = 0x75,
    FU_HAILUCK_CMD_WRITE_BLOCK = 0x77,
    FU_HAILUCK_CMD_GET_STATUS = 0xA1,
    FU_HAILUCK_CMD_WRITE_TP = 0xD0,
    FU_HAILUCK_CMD_I2C_CHECK_CHECKSUM = 0xF0,
    FU_HAILUCK_CMD_I2C_ENTER_BL = 0xF1,
    FU_HAILUCK_CMD_I2C_ERASE = 0xF2,
    FU_HAILUCK_CMD_I2C_PROGRAM = 0xF3,
    FU_HAILUCK_CMD_I2C_VERIFY_BLOCK = 0xF4,
    FU_HAILUCK_CMD_I2C_VERIFY_CHECKSUM = 0xF5,
    FU_HAILUCK_CMD_I2C_PROGRAMPASS = 0xF6,
    FU_HAILUCK_CMD_I2C_END_PROGRAM = 0xF7,
} FuHailuckCmd;
const gchar *fu_hailuck_cmd_to_string(FuHailuckCmd val);
