/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_PXI_OTA_SPEC_CHECK_RESULT_OK = 1,
    FU_PXI_OTA_SPEC_CHECK_RESULT_FW_OUT_OF_BOUNDS = 2,
    FU_PXI_OTA_SPEC_CHECK_RESULT_PROCESS_ILLEGAL = 3,
    FU_PXI_OTA_SPEC_CHECK_RESULT_RECONNECT = 4,
    FU_PXI_OTA_SPEC_CHECK_RESULT_FW_IMG_VERSION_ERROR = 5,
    FU_PXI_OTA_SPEC_CHECK_RESULT_DEVICE_LOW_BATTERY = 6,
} FuPxiOtaSpecCheckResult;
const gchar *fu_pxi_ota_spec_check_result_to_string(FuPxiOtaSpecCheckResult val);
typedef enum {
    FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_OK,
    FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_FINISH,
    FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_FAIL,
    FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_ERROR,
    FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_WRITE_PKT_LEN_ERROR,
    FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_WRITE_PKT_TOTAL_SIZE_ERROR,
    FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_READ_PKT_LEN_ERROR,
    FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_NOT_READY,
} FuPxiWirelessModuleOtaRspCode;
const gchar *fu_pxi_wireless_module_ota_rsp_code_to_string(FuPxiWirelessModuleOtaRspCode val);
