/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_EP963X_SMBUS_ERROR_NONE = 0x00,
    FU_EP963X_SMBUS_ERROR_ADDRESS = 0x01,
    FU_EP963X_SMBUS_ERROR_NO_ACK = 0x02,
    FU_EP963X_SMBUS_ERROR_ARBITRATION = 0x04,
    FU_EP963X_SMBUS_ERROR_COMMAND = 0x08,
    FU_EP963X_SMBUS_ERROR_TIMEOUT = 0x10,
    FU_EP963X_SMBUS_ERROR_BUSY = 0x20,
} FuEp963xSmbusError;
const gchar *fu_ep963x_smbus_error_to_string(FuEp963xSmbusError val);
