/* auto-generated, do not modify */
#include "config.h"

#include "fu-mei-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_mei_family_to_string(FuMeiFamily val)
{
    if (val == FU_MEI_FAMILY_UNKNOWN)
        return "unknown";
    if (val == FU_MEI_FAMILY_SPS)
        return "sps";
    if (val == FU_MEI_FAMILY_TXE)
        return "txe";
    if (val == FU_MEI_FAMILY_ME)
        return "me";
    if (val == FU_MEI_FAMILY_CSME)
        return "csme";
    return NULL;
}

const gchar *
fu_me_hfs_cws_to_string(FuMeHfsCws val)
{
    if (val == FU_ME_HFS_CWS_RESET)
        return "reset";
    if (val == FU_ME_HFS_CWS_INITIALIZING)
        return "initializing";
    if (val == FU_ME_HFS_CWS_RECOVERY)
        return "recovery";
    if (val == FU_ME_HFS_CWS_TEST)
        return "test";
    if (val == FU_ME_HFS_CWS_DISABLED)
        return "disabled";
    if (val == FU_ME_HFS_CWS_NORMAL)
        return "normal";
    if (val == FU_ME_HFS_CWS_WAIT)
        return "wait";
    if (val == FU_ME_HFS_CWS_TRANSITION)
        return "transition";
    if (val == FU_ME_HFS_CWS_INVALID)
        return "invalid";
    return NULL;
}

const gchar *
fu_me_hfs_state_to_string(FuMeHfsState val)
{
    if (val == FU_ME_HFS_STATE_PREBOOT)
        return "preboot";
    if (val == FU_ME_HFS_STATE_M0_WITH_UMA)
        return "m0-with-uma";
    if (val == FU_ME_HFS_STATE_M3_WITHOUT_UMA)
        return "m3-without-uma";
    if (val == FU_ME_HFS_STATE_M0_WITHOUT_UMA)
        return "m0-without-uma";
    if (val == FU_ME_HFS_STATE_BRING_UP)
        return "bring-up";
    if (val == FU_ME_HFS_STATE_ERROR)
        return "error";
    return NULL;
}

const gchar *
fu_me_hfs_mode_to_string(FuMeHfsMode val)
{
    if (val == FU_ME_HFS_MODE_NORMAL)
        return "normal";
    if (val == FU_ME_HFS_MODE_DEBUG)
        return "debug";
    if (val == FU_ME_HFS_MODE_DISABLE)
        return "disable";
    if (val == FU_ME_HFS_MODE_OVERRIDE_JUMPER)
        return "override-jumper";
    if (val == FU_ME_HFS_MODE_OVERRIDE_MEI)
        return "override-mei";
    if (val == FU_ME_HFS_MODE_UNKNOWN6)
        return "unknown6";
    if (val == FU_ME_HFS_MODE_MAYBE_SPS)
        return "maybe-sps";
    return NULL;
}

const gchar *
fu_me_hfs_error_to_string(FuMeHfsError val)
{
    if (val == FU_ME_HFS_ERROR_NO_ERROR)
        return "no-error";
    if (val == FU_ME_HFS_ERROR_UNCATEGORIZED_FAILURE)
        return "uncategorized-failure";
    if (val == FU_ME_HFS_ERROR_DISABLED)
        return "disabled";
    if (val == FU_ME_HFS_ERROR_IMAGE_FAILURE)
        return "image-failure";
    if (val == FU_ME_HFS_ERROR_DEBUG_FAILURE)
        return "debug-failure";
    return NULL;
}

