/* auto-generated, do not modify */
#include "config.h"

#include "fu-efi-image-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"
/* getters */
/**
 * fu_struct_efi_image_data_dir_entry_get_addr: (skip):
 **/
guint32
fu_struct_efi_image_data_dir_entry_get_addr(const GByteArray *st)
{
    g_return_val_if_fail(st != NULL, 0x0);
    return fu_memread_uint32(st->data + 0, G_LITTLE_ENDIAN);
}
/**
 * fu_struct_efi_image_data_dir_entry_get_size: (skip):
 **/
guint32
fu_struct_efi_image_data_dir_entry_get_size(const GByteArray *st)
{
    g_return_val_if_fail(st != NULL, 0x0);
    return fu_memread_uint32(st->data + 4, G_LITTLE_ENDIAN);
}

/* setters */
