/* auto-generated, do not modify */
#include "config.h"

#include "fu-mediatek-scaler-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"




const gchar *
fu_ddcci_priority_to_string(FuDdcciPriority val)
{
    if (val == FU_DDCCI_PRIORITY_NORMAL)
        return "normal";
    if (val == FU_DDCCI_PRIORITY_UP)
        return "up";
    return NULL;
}
/* getters */

/* setters */
/**
 * fu_struct_ddc_cmd_set_opcode: (skip):
 **/
void
fu_struct_ddc_cmd_set_opcode(GByteArray *st, FuDdcOpcode value)
{
    g_return_if_fail(st != NULL);
    st->data[0] = value;
}
/**
 * fu_struct_ddc_cmd_set_vcp_code: (skip):
 **/
void
fu_struct_ddc_cmd_set_vcp_code(GByteArray *st, FuDdcVcpCode value)
{
    g_return_if_fail(st != NULL);
    st->data[1] = value;
}
/**
 * fu_struct_ddc_cmd_new: (skip):
 **/
GByteArray *
fu_struct_ddc_cmd_new(void)
{
    GByteArray *st = g_byte_array_sized_new(2);
    fu_byte_array_set_size(st, 2, 0x0);
    fu_struct_ddc_cmd_set_opcode(st, FU_DDC_OPCODE_REQ);
    return st;
}
