/* auto-generated, do not modify */
#include "config.h"

#include "fu-colorhug-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_colorhug_error_to_string(FuColorhugError val)
{
    if (val == FU_COLORHUG_ERROR_NONE)
        return "none";
    if (val == FU_COLORHUG_ERROR_UNKNOWN_CMD)
        return "unknown-cmd";
    if (val == FU_COLORHUG_ERROR_WRONG_UNLOCK_CODE)
        return "wrong-unlock-code";
    if (val == FU_COLORHUG_ERROR_NOT_IMPLEMENTED)
        return "not-implemented";
    if (val == FU_COLORHUG_ERROR_UNDERFLOW_SENSOR)
        return "underflow-sensor";
    if (val == FU_COLORHUG_ERROR_NO_SERIAL)
        return "no-serial";
    if (val == FU_COLORHUG_ERROR_WATCHDOG)
        return "watchdog";
    if (val == FU_COLORHUG_ERROR_INVALID_ADDRESS)
        return "invalid-address";
    if (val == FU_COLORHUG_ERROR_INVALID_LENGTH)
        return "invalid-length";
    if (val == FU_COLORHUG_ERROR_INVALID_CHECKSUM)
        return "invalid-checksum";
    if (val == FU_COLORHUG_ERROR_INVALID_VALUE)
        return "invalid-value";
    if (val == FU_COLORHUG_ERROR_UNKNOWN_CMD_FOR_BOOTLOADER)
        return "unknown-cmd-for-bootloader";
    if (val == FU_COLORHUG_ERROR_NO_CALIBRATION)
        return "no-calibration";
    if (val == FU_COLORHUG_ERROR_OVERFLOW_MULTIPLY)
        return "overflow-multiply";
    if (val == FU_COLORHUG_ERROR_OVERFLOW_ADDITION)
        return "overflow-addition";
    if (val == FU_COLORHUG_ERROR_OVERFLOW_SENSOR)
        return "overflow-sensor";
    if (val == FU_COLORHUG_ERROR_OVERFLOW_STACK)
        return "overflow-stack";
    if (val == FU_COLORHUG_ERROR_DEVICE_DEACTIVATED)
        return "device-deactivated";
    if (val == FU_COLORHUG_ERROR_INCOMPLETE_REQUEST)
        return "incomplete-request";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_SENSOR)
        return "self-test-sensor";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_RED)
        return "self-test-red";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_GREEN)
        return "self-test-green";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_BLUE)
        return "self-test-blue";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_COLOR_SELECT)
        return "self-test-color-select";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_MULTIPLIER)
        return "self-test-multiplier";
    if (val == FU_COLORHUG_ERROR_INVALID_CALIBRATION)
        return "invalid-calibration";
    if (val == FU_COLORHUG_ERROR_SRAM_FAILED)
        return "sram-failed";
    if (val == FU_COLORHUG_ERROR_OUT_OF_MEMORY)
        return "out-of-memory";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_TEMPERATURE)
        return "self-test-temperature";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_I2C)
        return "self-test-i2c";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_ADC_VDD)
        return "self-test-adc-vdd";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_ADC_VSS)
        return "self-test-adc-vss";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_ADC_VREF)
        return "self-test-adc-vref";
    if (val == FU_COLORHUG_ERROR_I2C_TARGET_ADDRESS)
        return "i2c-target-address";
    if (val == FU_COLORHUG_ERROR_I2C_TARGET_CONFIG)
        return "i2c-target-config";
    if (val == FU_COLORHUG_ERROR_SELF_TEST_EEPROM)
        return "self-test-eeprom";
    return NULL;
}
