/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_INTEL_USB4_OPCODE_NVM_WRITE = 0x20,
    FU_INTEL_USB4_OPCODE_NVM_AUTH_WRITE = 0x21,
    FU_INTEL_USB4_OPCODE_NVM_READ = 0x22,
    FU_INTEL_USB4_OPCODE_NVM_SET_OFFSET = 0x23,
    FU_INTEL_USB4_OPCODE_DROM_READ = 0x24,
} FuIntelUsb4Opcode;

GByteArray *fu_struct_intel_usb4_mbox_new(void);
GByteArray *fu_struct_intel_usb4_mbox_parse(const guint8 *buf, gsize bufsz, gsize offset, GError **error);
FuIntelUsb4Opcode fu_struct_intel_usb4_mbox_get_opcode(const GByteArray *st);
guint8 fu_struct_intel_usb4_mbox_get_status(const GByteArray *st);
void fu_struct_intel_usb4_mbox_set_opcode(GByteArray *st, FuIntelUsb4Opcode value);
void fu_struct_intel_usb4_mbox_set_status(GByteArray *st, guint8 value);
#define FU_STRUCT_INTEL_USB4_MBOX_OFFSET_OPCODE 0x0
#define FU_STRUCT_INTEL_USB4_MBOX_OFFSET_STATUS 0x3
#define FU_STRUCT_INTEL_USB4_MBOX_SIZE 0x4
