/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>

GByteArray *fu_struct_acpi_phat_health_record_new(void);
GByteArray *fu_struct_acpi_phat_health_record_parse_bytes(GBytes *blob, gsize offset, GError **error);
guint16 fu_struct_acpi_phat_health_record_get_signature(const GByteArray *st);
guint16 fu_struct_acpi_phat_health_record_get_rcdlen(const GByteArray *st);
guint8 fu_struct_acpi_phat_health_record_get_version(const GByteArray *st);
guint8 fu_struct_acpi_phat_health_record_get_flags(const GByteArray *st);
const fwupd_guid_t *fu_struct_acpi_phat_health_record_get_device_signature(const GByteArray *st);
guint32 fu_struct_acpi_phat_health_record_get_device_specific_data(const GByteArray *st);
void fu_struct_acpi_phat_health_record_set_signature(GByteArray *st, guint16 value);
void fu_struct_acpi_phat_health_record_set_rcdlen(GByteArray *st, guint16 value);
void fu_struct_acpi_phat_health_record_set_version(GByteArray *st, guint8 value);
void fu_struct_acpi_phat_health_record_set_flags(GByteArray *st, guint8 value);
void fu_struct_acpi_phat_health_record_set_device_signature(GByteArray *st, const fwupd_guid_t *value);
void fu_struct_acpi_phat_health_record_set_device_specific_data(GByteArray *st, guint32 value);
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_OFFSET_SIGNATURE 0x0
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_OFFSET_RCDLEN 0x2
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_OFFSET_VERSION 0x4
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_OFFSET_FLAGS 0x7
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_OFFSET_DEVICE_SIGNATURE 0x8
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_OFFSET_DEVICE_SPECIFIC_DATA 0x18
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_SIZE_DEVICE_SIGNATURE 0x10
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_SIZE 0x1C
#define FU_STRUCT_ACPI_PHAT_HEALTH_RECORD_DEFAULT_SIGNATURE 0x1

GByteArray *fu_struct_acpi_phat_version_element_new(void);
GByteArray *fu_struct_acpi_phat_version_element_parse_bytes(GBytes *blob, gsize offset, GError **error);
const fwupd_guid_t *fu_struct_acpi_phat_version_element_get_component_id(const GByteArray *st);
guint64 fu_struct_acpi_phat_version_element_get_version_value(const GByteArray *st);
gchar *fu_struct_acpi_phat_version_element_get_producer_id(const GByteArray *st);
void fu_struct_acpi_phat_version_element_set_component_id(GByteArray *st, const fwupd_guid_t *value);
void fu_struct_acpi_phat_version_element_set_version_value(GByteArray *st, guint64 value);
gboolean fu_struct_acpi_phat_version_element_set_producer_id(GByteArray *st, const gchar *value, GError **error);
#define FU_STRUCT_ACPI_PHAT_VERSION_ELEMENT_OFFSET_COMPONENT_ID 0x0
#define FU_STRUCT_ACPI_PHAT_VERSION_ELEMENT_OFFSET_VERSION_VALUE 0x10
#define FU_STRUCT_ACPI_PHAT_VERSION_ELEMENT_OFFSET_PRODUCER_ID 0x18
#define FU_STRUCT_ACPI_PHAT_VERSION_ELEMENT_SIZE_COMPONENT_ID 0x10
#define FU_STRUCT_ACPI_PHAT_VERSION_ELEMENT_SIZE_PRODUCER_ID 0x4
#define FU_STRUCT_ACPI_PHAT_VERSION_ELEMENT_SIZE 0x1C

GByteArray *fu_struct_acpi_phat_version_record_new(void);
GByteArray *fu_struct_acpi_phat_version_record_parse_bytes(GBytes *blob, gsize offset, GError **error);
guint16 fu_struct_acpi_phat_version_record_get_signature(const GByteArray *st);
guint16 fu_struct_acpi_phat_version_record_get_rcdlen(const GByteArray *st);
guint8 fu_struct_acpi_phat_version_record_get_version(const GByteArray *st);
guint32 fu_struct_acpi_phat_version_record_get_record_count(const GByteArray *st);
void fu_struct_acpi_phat_version_record_set_signature(GByteArray *st, guint16 value);
void fu_struct_acpi_phat_version_record_set_rcdlen(GByteArray *st, guint16 value);
void fu_struct_acpi_phat_version_record_set_version(GByteArray *st, guint8 value);
void fu_struct_acpi_phat_version_record_set_record_count(GByteArray *st, guint32 value);
#define FU_STRUCT_ACPI_PHAT_VERSION_RECORD_OFFSET_SIGNATURE 0x0
#define FU_STRUCT_ACPI_PHAT_VERSION_RECORD_OFFSET_RCDLEN 0x2
#define FU_STRUCT_ACPI_PHAT_VERSION_RECORD_OFFSET_VERSION 0x4
#define FU_STRUCT_ACPI_PHAT_VERSION_RECORD_OFFSET_RECORD_COUNT 0x8
#define FU_STRUCT_ACPI_PHAT_VERSION_RECORD_SIZE 0xC
#define FU_STRUCT_ACPI_PHAT_VERSION_RECORD_DEFAULT_SIGNATURE 0x0
