/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_RELEASE_PRIORITY_NONE,
    FU_RELEASE_PRIORITY_LOCAL,
    FU_RELEASE_PRIORITY_REMOTE,
} FuReleasePriority;
FuReleasePriority fu_release_priority_from_string(const gchar *val);
typedef enum {
    FU_P2P_POLICY_NOTHING = 0x00,
    FU_P2P_POLICY_METADATA = 0x01,
    FU_P2P_POLICY_FIRMWARE = 0x02,
} FuP2pPolicy;
FuP2pPolicy fu_p2p_policy_from_string(const gchar *val);
typedef enum {
    FU_ENGINE_INSTALL_PHASE_SETUP,
    FU_ENGINE_INSTALL_PHASE_INSTALL,
    FU_ENGINE_INSTALL_PHASE_ATTACH,
    FU_ENGINE_INSTALL_PHASE_DETACH,
    FU_ENGINE_INSTALL_PHASE_PREPARE,
    FU_ENGINE_INSTALL_PHASE_CLEANUP,
    FU_ENGINE_INSTALL_PHASE_RELOAD,
    FU_ENGINE_INSTALL_PHASE_COMPOSITE_PREPARE,
    FU_ENGINE_INSTALL_PHASE_COMPOSITE_CLEANUP,
    FU_ENGINE_INSTALL_PHASE_LAST,
} FuEngineInstallPhase;
const gchar *fu_engine_install_phase_to_string(FuEngineInstallPhase val);
typedef enum {
    FU_ENGINE_REQUEST_FLAG_NONE = 0,
    FU_ENGINE_REQUEST_FLAG_NO_REQUIREMENTS = 1<<0,
    FU_ENGINE_REQUEST_FLAG_ANY_RELEASE = 1<<1,
} FuEngineRequestFlag;
gchar *fu_engine_request_flag_to_string(FuEngineRequestFlag val);
typedef enum {
    FU_IDLE_INHIBIT_NONE = 0,
    FU_IDLE_INHIBIT_TIMEOUT = 1<<0,
    FU_IDLE_INHIBIT_SIGNALS = 1<<1,
} FuIdleInhibit;
gchar *fu_idle_inhibit_to_string(FuIdleInhibit val);
typedef enum {
    FU_CLIENT_FLAG_NONE = 0,
    FU_CLIENT_FLAG_ACTIVE = 1<<0,
} FuClientFlag;
