/* auto-generated, do not modify */
#include "config.h"

#include "fu-scsi-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_scsi_sense_key_to_string(FuScsiSenseKey val)
{
    if (val == FU_SCSI_SENSE_KEY_NO_SENSE)
        return "no-sense";
    if (val == FU_SCSI_SENSE_KEY_RECOVERED_ERROR)
        return "recovered-error";
    if (val == FU_SCSI_SENSE_KEY_NOT_READY)
        return "not-ready";
    if (val == FU_SCSI_SENSE_KEY_MEDIUM_ERROR)
        return "medium-error";
    if (val == FU_SCSI_SENSE_KEY_HARDWARE_ERROR)
        return "hardware-error";
    if (val == FU_SCSI_SENSE_KEY_ILLEGAL_REQUEST)
        return "illegal-request";
    if (val == FU_SCSI_SENSE_KEY_UNIT_ATTENTION)
        return "unit-attention";
    if (val == FU_SCSI_SENSE_KEY_DATA_PROTECT)
        return "data-protect";
    if (val == FU_SCSI_SENSE_KEY_BLANK_CHECK)
        return "blank-check";
    if (val == FU_SCSI_SENSE_KEY_VENDOR_SPECIFIC)
        return "vendor-specific";
    if (val == FU_SCSI_SENSE_KEY_COPY_ABORTED)
        return "copy-aborted";
    if (val == FU_SCSI_SENSE_KEY_ABORTED_COMMAND)
        return "aborted-command";
    if (val == FU_SCSI_SENSE_KEY_EQUAL)
        return "equal";
    if (val == FU_SCSI_SENSE_KEY_VOLUME_OVERFLOW)
        return "volume-overflow";
    if (val == FU_SCSI_SENSE_KEY_MISCOMPARE)
        return "miscompare";
    return NULL;
}
