/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>

GByteArray *fu_struct_acpi_table_new(void);
GByteArray *fu_struct_acpi_table_parse(const guint8 *buf, gsize bufsz, gsize offset, GError **error);
gchar *fu_struct_acpi_table_get_signature(const GByteArray *st);
guint32 fu_struct_acpi_table_get_length(const GByteArray *st);
guint8 fu_struct_acpi_table_get_revision(const GByteArray *st);
guint8 fu_struct_acpi_table_get_checksum(const GByteArray *st);
gchar *fu_struct_acpi_table_get_oem_id(const GByteArray *st);
gchar *fu_struct_acpi_table_get_oem_table_id(const GByteArray *st);
guint32 fu_struct_acpi_table_get_oem_revision(const GByteArray *st);
gboolean fu_struct_acpi_table_set_signature(GByteArray *st, const gchar *value, GError **error);
void fu_struct_acpi_table_set_length(GByteArray *st, guint32 value);
void fu_struct_acpi_table_set_revision(GByteArray *st, guint8 value);
void fu_struct_acpi_table_set_checksum(GByteArray *st, guint8 value);
gboolean fu_struct_acpi_table_set_oem_id(GByteArray *st, const gchar *value, GError **error);
gboolean fu_struct_acpi_table_set_oem_table_id(GByteArray *st, const gchar *value, GError **error);
void fu_struct_acpi_table_set_oem_revision(GByteArray *st, guint32 value);
#define FU_STRUCT_ACPI_TABLE_OFFSET_SIGNATURE 0x0
#define FU_STRUCT_ACPI_TABLE_OFFSET_LENGTH 0x4
#define FU_STRUCT_ACPI_TABLE_OFFSET_REVISION 0x8
#define FU_STRUCT_ACPI_TABLE_OFFSET_CHECKSUM 0x9
#define FU_STRUCT_ACPI_TABLE_OFFSET_OEM_ID 0xA
#define FU_STRUCT_ACPI_TABLE_OFFSET_OEM_TABLE_ID 0x10
#define FU_STRUCT_ACPI_TABLE_OFFSET_OEM_REVISION 0x18
#define FU_STRUCT_ACPI_TABLE_SIZE_SIGNATURE 0x4
#define FU_STRUCT_ACPI_TABLE_SIZE_OEM_ID 0x6
#define FU_STRUCT_ACPI_TABLE_SIZE_OEM_TABLE_ID 0x8
#define FU_STRUCT_ACPI_TABLE_SIZE 0x24
