/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_INTEL_THUNDERBOLT_NVM_SECTION_DIGITAL,
    FU_INTEL_THUNDERBOLT_NVM_SECTION_DROM,
    FU_INTEL_THUNDERBOLT_NVM_SECTION_ARC_PARAMS,
    FU_INTEL_THUNDERBOLT_NVM_SECTION_DRAM_UCODE,
    FU_INTEL_THUNDERBOLT_NVM_SECTION_LAST,
} FuIntelThunderboltNvmSection;
const gchar *fu_intel_thunderbolt_nvm_section_to_string(FuIntelThunderboltNvmSection val);
typedef enum {
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_UNKNOWN,
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_FALCON_RIDGE,
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_WIN_RIDGE,
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_ALPINE_RIDGE,
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_ALPINE_RIDGE_C,
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_TITAN_RIDGE,
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_BB,
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_MAPLE_RIDGE,
    FU_INTEL_THUNDERBOLT_NVM_FAMILY_GOSHEN_RIDGE,
} FuIntelThunderboltNvmFamily;
const gchar *fu_intel_thunderbolt_nvm_family_to_string(FuIntelThunderboltNvmFamily val);
FuIntelThunderboltNvmFamily fu_intel_thunderbolt_nvm_family_from_string(const gchar *val);
