/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_FPC_DFU_STATE_DNBUSY = 0x04,
} FuFpcDfuState;

GByteArray *fu_struct_fpc_dfu_new(void);
guint8 fu_struct_fpc_dfu_get_status(const GByteArray *st);
guint8 fu_struct_fpc_dfu_get_max_payload_size(const GByteArray *st);
FuFpcDfuState fu_struct_fpc_dfu_get_state(const GByteArray *st);
void fu_struct_fpc_dfu_set_status(GByteArray *st, guint8 value);
void fu_struct_fpc_dfu_set_max_payload_size(GByteArray *st, guint8 value);
void fu_struct_fpc_dfu_set_state(GByteArray *st, FuFpcDfuState value);
#define FU_STRUCT_FPC_DFU_OFFSET_STATUS 0x0
#define FU_STRUCT_FPC_DFU_OFFSET_MAX_PAYLOAD_SIZE 0x1
#define FU_STRUCT_FPC_DFU_OFFSET_STATE 0x4
#define FU_STRUCT_FPC_DFU_SIZE 0x6
