/* auto-generated, do not modify */
#include "config.h"

#include "fu-logitech-hidpp-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_logitech_hidpp_feature_to_string(FuLogitechHidppFeature val)
{
    if (val == FU_LOGITECH_HIDPP_FEATURE_ROOT)
        return "root";
    if (val == FU_LOGITECH_HIDPP_FEATURE_I_FEATURE_SET)
        return "i-feature-set";
    if (val == FU_LOGITECH_HIDPP_FEATURE_I_FIRMWARE_INFO)
        return "i-firmware-info";
    if (val == FU_LOGITECH_HIDPP_FEATURE_GET_DEVICE_NAME_TYPE)
        return "get-device-name-type";
    if (val == FU_LOGITECH_HIDPP_FEATURE_DFU_CONTROL)
        return "dfu-control";
    if (val == FU_LOGITECH_HIDPP_FEATURE_DFU_CONTROL_SIGNED)
        return "dfu-control-signed";
    if (val == FU_LOGITECH_HIDPP_FEATURE_DFU_CONTROL_BOLT)
        return "dfu-control-bolt";
    if (val == FU_LOGITECH_HIDPP_FEATURE_DFU)
        return "dfu";
    if (val == FU_LOGITECH_HIDPP_FEATURE_BATTERY_LEVEL_STATUS)
        return "battery-level-status";
    if (val == FU_LOGITECH_HIDPP_FEATURE_UNIFIED_BATTERY)
        return "unified-battery";
    if (val == FU_LOGITECH_HIDPP_FEATURE_KBD_REPROGRAMMABLE_KEYS)
        return "kbd-reprogrammable-keys";
    if (val == FU_LOGITECH_HIDPP_FEATURE_SPECIAL_KEYS_BUTTONS)
        return "special-keys-buttons";
    if (val == FU_LOGITECH_HIDPP_FEATURE_MOUSE_POINTER_BASIC)
        return "mouse-pointer-basic";
    if (val == FU_LOGITECH_HIDPP_FEATURE_ADJUSTABLE_DPI)
        return "adjustable-dpi";
    if (val == FU_LOGITECH_HIDPP_FEATURE_ADJUSTABLE_REPORT_RATE)
        return "adjustable-report-rate";
    if (val == FU_LOGITECH_HIDPP_FEATURE_COLOR_LED_EFFECTS)
        return "color-led-effects";
    if (val == FU_LOGITECH_HIDPP_FEATURE_ONBOARD_PROFILES)
        return "onboard-profiles";
    if (val == FU_LOGITECH_HIDPP_FEATURE_MOUSE_BUTTON_SPY)
        return "mouse-button-spy";
    return NULL;
}

const gchar *
fu_logitech_hidpp_device_idx_to_string(FuLogitechHidppDeviceIdx val)
{
    if (val == FU_LOGITECH_HIDPP_DEVICE_IDX_WIRED)
        return "wired";
    if (val == FU_LOGITECH_HIDPP_DEVICE_IDX_RECEIVER)
        return "receiver";
    return NULL;
}

const gchar *
fu_logitech_hidpp_report_id_to_string(FuLogitechHidppReportId val)
{
    if (val == FU_LOGITECH_HIDPP_REPORT_ID_SHORT)
        return "short";
    if (val == FU_LOGITECH_HIDPP_REPORT_ID_LONG)
        return "long";
    if (val == FU_LOGITECH_HIDPP_REPORT_ID_VERY_LONG)
        return "very-long";
    return NULL;
}

const gchar *
fu_logitech_hidpp_register_to_string(FuLogitechHidppRegister val)
{
    if (val == FU_LOGITECH_HIDPP_REGISTER_HIDPP_NOTIFICATIONS)
        return "hidpp-notifications";
    if (val == FU_LOGITECH_HIDPP_REGISTER_ENABLE_INDIVIDUAL_FEATURES)
        return "enable-individual-features";
    if (val == FU_LOGITECH_HIDPP_REGISTER_BATTERY_STATUS)
        return "battery-status";
    if (val == FU_LOGITECH_HIDPP_REGISTER_BATTERY_MILEAGE)
        return "battery-mileage";
    if (val == FU_LOGITECH_HIDPP_REGISTER_PROFILE)
        return "profile";
    if (val == FU_LOGITECH_HIDPP_REGISTER_LED_STATUS)
        return "led-status";
    if (val == FU_LOGITECH_HIDPP_REGISTER_LED_INTENSITY)
        return "led-intensity";
    if (val == FU_LOGITECH_HIDPP_REGISTER_LED_COLOR)
        return "led-color";
    if (val == FU_LOGITECH_HIDPP_REGISTER_OPTICAL_SENSOR_SETTINGS)
        return "optical-sensor-settings";
    if (val == FU_LOGITECH_HIDPP_REGISTER_CURRENT_RESOLUTION)
        return "current-resolution";
    if (val == FU_LOGITECH_HIDPP_REGISTER_USB_REFRESH_RATE)
        return "usb-refresh-rate";
    if (val == FU_LOGITECH_HIDPP_REGISTER_GENERIC_MEMORY_MANAGEMENT)
        return "generic-memory-management";
    if (val == FU_LOGITECH_HIDPP_REGISTER_HOT_CONTROL)
        return "hot-control";
    if (val == FU_LOGITECH_HIDPP_REGISTER_READ_MEMORY)
        return "read-memory";
    if (val == FU_LOGITECH_HIDPP_REGISTER_DEVICE_CONNECTION_DISCONNECTION)
        return "device-connection-disconnection";
    if (val == FU_LOGITECH_HIDPP_REGISTER_PAIRING_INFORMATION)
        return "pairing-information";
    if (val == FU_LOGITECH_HIDPP_REGISTER_DEVICE_FIRMWARE_UPDATE_MODE)
        return "device-firmware-update-mode";
    if (val == FU_LOGITECH_HIDPP_REGISTER_DEVICE_FIRMWARE_INFORMATION)
        return "device-firmware-information";
    return NULL;
}

const gchar *
fu_logitech_hidpp_subid_to_string(FuLogitechHidppSubid val)
{
    if (val == FU_LOGITECH_HIDPP_SUBID_VENDOR_SPECIFIC_KEYS)
        return "vendor-specific-keys";
    if (val == FU_LOGITECH_HIDPP_SUBID_POWER_KEYS)
        return "power-keys";
    if (val == FU_LOGITECH_HIDPP_SUBID_ROLLER)
        return "roller";
    if (val == FU_LOGITECH_HIDPP_SUBID_MOUSE_EXTRA_BUTTONS)
        return "mouse-extra-buttons";
    if (val == FU_LOGITECH_HIDPP_SUBID_BATTERY_CHARGING_LEVEL)
        return "battery-charging-level";
    if (val == FU_LOGITECH_HIDPP_SUBID_USER_INTERFACE_EVENT)
        return "user-interface-event";
    if (val == FU_LOGITECH_HIDPP_SUBID_F_LOCK_STATUS)
        return "f-lock-status";
    if (val == FU_LOGITECH_HIDPP_SUBID_CALCULATOR_RESULT)
        return "calculator-result";
    if (val == FU_LOGITECH_HIDPP_SUBID_MENU_NAVIGATE)
        return "menu-navigate";
    if (val == FU_LOGITECH_HIDPP_SUBID_FN_KEY)
        return "fn-key";
    if (val == FU_LOGITECH_HIDPP_SUBID_BATTERY_MILEAGE)
        return "battery-mileage";
    if (val == FU_LOGITECH_HIDPP_SUBID_UART_RX)
        return "uart-rx";
    if (val == FU_LOGITECH_HIDPP_SUBID_BACKLIGHT_DURATION_UPDATE)
        return "backlight-duration-update";
    if (val == FU_LOGITECH_HIDPP_SUBID_DEVICE_DISCONNECTION)
        return "device-disconnection";
    if (val == FU_LOGITECH_HIDPP_SUBID_DEVICE_CONNECTION)
        return "device-connection";
    if (val == FU_LOGITECH_HIDPP_SUBID_DEVICE_DISCOVERY)
        return "device-discovery";
    if (val == FU_LOGITECH_HIDPP_SUBID_PIN_CODE_REQUEST)
        return "pin-code-request";
    if (val == FU_LOGITECH_HIDPP_SUBID_RECEIVER_WORKING_MODE)
        return "receiver-working-mode";
    if (val == FU_LOGITECH_HIDPP_SUBID_ERROR_MESSAGE)
        return "error-message";
    if (val == FU_LOGITECH_HIDPP_SUBID_RF_LINK_CHANGE)
        return "rf-link-change";
    if (val == FU_LOGITECH_HIDPP_SUBID_HCI)
        return "hci";
    if (val == FU_LOGITECH_HIDPP_SUBID_LINK_QUALITY)
        return "link-quality";
    if (val == FU_LOGITECH_HIDPP_SUBID_DEVICE_LOCKING_CHANGED)
        return "device-locking-changed";
    if (val == FU_LOGITECH_HIDPP_SUBID_WIRELESS_DEVICE_CHANGE)
        return "wireless-device-change";
    if (val == FU_LOGITECH_HIDPP_SUBID_ACL)
        return "acl";
    if (val == FU_LOGITECH_HIDPP_SUBID_VOIP_TELEPHONY_EVENT)
        return "voip-telephony-event";
    if (val == FU_LOGITECH_HIDPP_SUBID_LED)
        return "led";
    if (val == FU_LOGITECH_HIDPP_SUBID_GESTURE_AND_AIR)
        return "gesture-and-air";
    if (val == FU_LOGITECH_HIDPP_SUBID_TOUCHPAD_MULTI_TOUCH)
        return "touchpad-multi-touch";
    if (val == FU_LOGITECH_HIDPP_SUBID_TRACEABILITY)
        return "traceability";
    if (val == FU_LOGITECH_HIDPP_SUBID_SET_REGISTER)
        return "set-register";
    if (val == FU_LOGITECH_HIDPP_SUBID_GET_REGISTER)
        return "get-register";
    if (val == FU_LOGITECH_HIDPP_SUBID_SET_LONG_REGISTER)
        return "set-long-register";
    if (val == FU_LOGITECH_HIDPP_SUBID_GET_LONG_REGISTER)
        return "get-long-register";
    if (val == FU_LOGITECH_HIDPP_SUBID_SET_VERY_LONG_REGISTER)
        return "set-very-long-register";
    if (val == FU_LOGITECH_HIDPP_SUBID_GET_VERY_LONG_REGISTER)
        return "get-very-long-register";
    if (val == FU_LOGITECH_HIDPP_SUBID_ERROR_MSG)
        return "error-msg";
    if (val == FU_LOGITECH_HIDPP_SUBID_ERROR_MSG_20)
        return "error-msg-20";
    return NULL;
}

