/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_SYNAPTICS_MST_FAMILY_UNKNOWN,
    FU_SYNAPTICS_MST_FAMILY_TESLA,
    FU_SYNAPTICS_MST_FAMILY_LEAF,
    FU_SYNAPTICS_MST_FAMILY_PANAMERA,
    FU_SYNAPTICS_MST_FAMILY_CAYENNE,
    FU_SYNAPTICS_MST_FAMILY_SPYDER,
} FuSynapticsMstFamily;
const gchar *fu_synaptics_mst_family_to_string(FuSynapticsMstFamily val);
typedef enum {
    FU_SYNAPTICS_MST_UPDC_RC_SUCCESS,
    FU_SYNAPTICS_MST_UPDC_RC_INVALID,
    FU_SYNAPTICS_MST_UPDC_RC_UNSUPPORTED,
    FU_SYNAPTICS_MST_UPDC_RC_FAILED,
    FU_SYNAPTICS_MST_UPDC_RC_DISABLED,
    FU_SYNAPTICS_MST_UPDC_RC_CONFIGURE_SIGN_FAILED,
    FU_SYNAPTICS_MST_UPDC_RC_FIRMWARE_SIGN_FAILED,
    FU_SYNAPTICS_MST_UPDC_RC_ROLLBACK_FAILED,
} FuSynapticsMstUpdcRc;
const gchar *fu_synaptics_mst_updc_rc_to_string(FuSynapticsMstUpdcRc val);
typedef enum {
    FU_SYNAPTICS_MST_UPDC_CMD_ENABLE_RC = 0x01,
    FU_SYNAPTICS_MST_UPDC_CMD_DISABLE_RC = 0x02,
    FU_SYNAPTICS_MST_UPDC_CMD_GET_ID = 0x03,
    FU_SYNAPTICS_MST_UPDC_CMD_GET_VERSION = 0x04,
    FU_SYNAPTICS_MST_UPDC_CMD_FLASH_MAPPING = 0x07,
    FU_SYNAPTICS_MST_UPDC_CMD_ENABLE_FLASH_CHIP_ERASE = 0x08,
    FU_SYNAPTICS_MST_UPDC_CMD_CAL_EEPROM_CHECKSUM = 0x11,
    FU_SYNAPTICS_MST_UPDC_CMD_FLASH_ERASE = 0x14,
    FU_SYNAPTICS_MST_UPDC_CMD_CAL_EEPROM_CHECK_CRC8 = 0x16,
    FU_SYNAPTICS_MST_UPDC_CMD_CAL_EEPROM_CHECK_CRC16 = 0x17,
    FU_SYNAPTICS_MST_UPDC_CMD_ACTIVATE_FIRMWARE = 0x18,
    FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_EEPROM = 0x20,
    FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_MEMORY = 0x21,
    FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_TX_DPCD = 0x22,
    FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_TX_DPCD_TX1 = 0x23,
    FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_TX_DPCD_TX2 = 0x24,
    FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_TX_DPCD_TX3 = 0x25,
    FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_EEPROM = 0x30,
    FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_MEMORY = 0x31,
    FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_TX_DPCD = 0x32,
    FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_TX_DPCD_TX1 = 0x33,
    FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_TX_DPCD_TX2 = 0x34,
    FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_TX_DPCD_TX3 = 0x35,
} FuSynapticsMstUpdcCmd;
const gchar *fu_synaptics_mst_updc_cmd_to_string(FuSynapticsMstUpdcCmd val);
typedef enum {
    FU_SYNAPTICS_MST_REG_RC_CAP = 0x4B0,
    FU_SYNAPTICS_MST_REG_RC_STATE = 0x4B1,
    FU_SYNAPTICS_MST_REG_RC_CMD = 0x4B2,
    FU_SYNAPTICS_MST_REG_RC_RESULT = 0x4B3,
    FU_SYNAPTICS_MST_REG_RC_LEN = 0x4B8,
    FU_SYNAPTICS_MST_REG_RC_OFFSET = 0x4BC,
    FU_SYNAPTICS_MST_REG_RC_DATA = 0x4C0,
} FuSynapticsMstRegRc;
