/* auto-generated, do not modify */
#include "config.h"

#include "fu-corsair-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_corsair_device_kind_to_string(FuCorsairDeviceKind val)
{
    if (val == FU_CORSAIR_DEVICE_KIND_UNKNOWN)
        return "unknown";
    if (val == FU_CORSAIR_DEVICE_KIND_MOUSE)
        return "mouse";
    if (val == FU_CORSAIR_DEVICE_KIND_RECEIVER)
        return "receiver";
    return NULL;
}
FuCorsairDeviceKind
fu_corsair_device_kind_from_string(const gchar *val)
{
    if (g_strcmp0(val, "unknown") == 0)
        return FU_CORSAIR_DEVICE_KIND_UNKNOWN;
    if (g_strcmp0(val, "mouse") == 0)
        return FU_CORSAIR_DEVICE_KIND_MOUSE;
    if (g_strcmp0(val, "receiver") == 0)
        return FU_CORSAIR_DEVICE_KIND_RECEIVER;
    return FU_CORSAIR_DEVICE_KIND_UNKNOWN;
}
