/* auto-generated, do not modify */
#include "config.h"

#include "fu-synaptics-mst-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_synaptics_mst_family_to_string(FuSynapticsMstFamily val)
{
    if (val == FU_SYNAPTICS_MST_FAMILY_UNKNOWN)
        return "unknown";
    if (val == FU_SYNAPTICS_MST_FAMILY_TESLA)
        return "tesla";
    if (val == FU_SYNAPTICS_MST_FAMILY_LEAF)
        return "leaf";
    if (val == FU_SYNAPTICS_MST_FAMILY_PANAMERA)
        return "panamera";
    if (val == FU_SYNAPTICS_MST_FAMILY_CAYENNE)
        return "cayenne";
    if (val == FU_SYNAPTICS_MST_FAMILY_SPYDER)
        return "spyder";
    return NULL;
}

const gchar *
fu_synaptics_mst_updc_rc_to_string(FuSynapticsMstUpdcRc val)
{
    if (val == FU_SYNAPTICS_MST_UPDC_RC_SUCCESS)
        return "success";
    if (val == FU_SYNAPTICS_MST_UPDC_RC_INVALID)
        return "invalid";
    if (val == FU_SYNAPTICS_MST_UPDC_RC_UNSUPPORTED)
        return "unsupported";
    if (val == FU_SYNAPTICS_MST_UPDC_RC_FAILED)
        return "failed";
    if (val == FU_SYNAPTICS_MST_UPDC_RC_DISABLED)
        return "disabled";
    if (val == FU_SYNAPTICS_MST_UPDC_RC_CONFIGURE_SIGN_FAILED)
        return "configure-sign-failed";
    if (val == FU_SYNAPTICS_MST_UPDC_RC_FIRMWARE_SIGN_FAILED)
        return "firmware-sign-failed";
    if (val == FU_SYNAPTICS_MST_UPDC_RC_ROLLBACK_FAILED)
        return "rollback-failed";
    return NULL;
}

const gchar *
fu_synaptics_mst_updc_cmd_to_string(FuSynapticsMstUpdcCmd val)
{
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_ENABLE_RC)
        return "enable-rc";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_DISABLE_RC)
        return "disable-rc";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_GET_ID)
        return "get-id";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_GET_VERSION)
        return "get-version";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_FLASH_MAPPING)
        return "flash-mapping";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_ENABLE_FLASH_CHIP_ERASE)
        return "enable-flash-chip-erase";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_CAL_EEPROM_CHECKSUM)
        return "cal-eeprom-checksum";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_FLASH_ERASE)
        return "flash-erase";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_CAL_EEPROM_CHECK_CRC8)
        return "cal-eeprom-check-crc8";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_CAL_EEPROM_CHECK_CRC16)
        return "cal-eeprom-check-crc16";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_ACTIVATE_FIRMWARE)
        return "activate-firmware";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_EEPROM)
        return "write-to-eeprom";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_MEMORY)
        return "write-to-memory";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_TX_DPCD)
        return "write-to-tx-dpcd";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_TX_DPCD_TX1)
        return "write-to-tx-dpcd-tx1";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_TX_DPCD_TX2)
        return "write-to-tx-dpcd-tx2";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_WRITE_TO_TX_DPCD_TX3)
        return "write-to-tx-dpcd-tx3";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_EEPROM)
        return "read-from-eeprom";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_MEMORY)
        return "read-from-memory";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_TX_DPCD)
        return "read-from-tx-dpcd";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_TX_DPCD_TX1)
        return "read-from-tx-dpcd-tx1";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_TX_DPCD_TX2)
        return "read-from-tx-dpcd-tx2";
    if (val == FU_SYNAPTICS_MST_UPDC_CMD_READ_FROM_TX_DPCD_TX3)
        return "read-from-tx-dpcd-tx3";
    return NULL;
}

