/* auto-generated, do not modify */
#include "config.h"

#include "fu-pxi-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_pxi_ota_spec_check_result_to_string(FuPxiOtaSpecCheckResult val)
{
    if (val == FU_PXI_OTA_SPEC_CHECK_RESULT_OK)
        return "ok";
    if (val == FU_PXI_OTA_SPEC_CHECK_RESULT_FW_OUT_OF_BOUNDS)
        return "fw-out-of-bounds";
    if (val == FU_PXI_OTA_SPEC_CHECK_RESULT_PROCESS_ILLEGAL)
        return "process-illegal";
    if (val == FU_PXI_OTA_SPEC_CHECK_RESULT_RECONNECT)
        return "reconnect";
    if (val == FU_PXI_OTA_SPEC_CHECK_RESULT_FW_IMG_VERSION_ERROR)
        return "fw-img-version-error";
    if (val == FU_PXI_OTA_SPEC_CHECK_RESULT_DEVICE_LOW_BATTERY)
        return "device-low-battery";
    return NULL;
}

const gchar *
fu_pxi_wireless_module_ota_rsp_code_to_string(FuPxiWirelessModuleOtaRspCode val)
{
    if (val == FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_OK)
        return "ok";
    if (val == FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_FINISH)
        return "finish";
    if (val == FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_FAIL)
        return "fail";
    if (val == FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_ERROR)
        return "error";
    if (val == FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_WRITE_PKT_LEN_ERROR)
        return "write-pkt-len-error";
    if (val == FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_WRITE_PKT_TOTAL_SIZE_ERROR)
        return "write-pkt-total-size-error";
    if (val == FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_READ_PKT_LEN_ERROR)
        return "read-pkt-len-error";
    if (val == FU_PXI_WIRELESS_MODULE_OTA_RSP_CODE_NOT_READY)
        return "not-ready";
    return NULL;
}
