/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_ARCHIVE_FORMAT_UNKNOWN,
    FU_ARCHIVE_FORMAT_CPIO,
    FU_ARCHIVE_FORMAT_SHAR,
    FU_ARCHIVE_FORMAT_TAR,
    FU_ARCHIVE_FORMAT_USTAR,
    FU_ARCHIVE_FORMAT_PAX,
    FU_ARCHIVE_FORMAT_GNUTAR,
    FU_ARCHIVE_FORMAT_ISO9660,
    FU_ARCHIVE_FORMAT_ZIP,
    FU_ARCHIVE_FORMAT_AR,
    FU_ARCHIVE_FORMAT_AR_SVR4,
    FU_ARCHIVE_FORMAT_MTREE,
    FU_ARCHIVE_FORMAT_RAW,
    FU_ARCHIVE_FORMAT_XAR,
    FU_ARCHIVE_FORMAT_7ZIP,
    FU_ARCHIVE_FORMAT_WARC,
} FuArchiveFormat;
const gchar *fu_archive_format_to_string(FuArchiveFormat val);
FuArchiveFormat fu_archive_format_from_string(const gchar *val);
typedef enum {
    FU_ARCHIVE_COMPRESSION_UNKNOWN,
    FU_ARCHIVE_COMPRESSION_NONE,
    FU_ARCHIVE_COMPRESSION_GZIP,
    FU_ARCHIVE_COMPRESSION_BZIP2,
    FU_ARCHIVE_COMPRESSION_COMPRESS,
    FU_ARCHIVE_COMPRESSION_LZMA,
    FU_ARCHIVE_COMPRESSION_XZ,
    FU_ARCHIVE_COMPRESSION_UU,
    FU_ARCHIVE_COMPRESSION_LZIP,
    FU_ARCHIVE_COMPRESSION_LRZIP,
    FU_ARCHIVE_COMPRESSION_LZOP,
    FU_ARCHIVE_COMPRESSION_GRZIP,
    FU_ARCHIVE_COMPRESSION_LZ4,
    FU_ARCHIVE_COMPRESSION_ZSTD,
} FuArchiveCompression;
const gchar *fu_archive_compression_to_string(FuArchiveCompression val);
FuArchiveCompression fu_archive_compression_from_string(const gchar *val);
