/* auto-generated, do not modify */
#include "config.h"

#include "fu-daemon-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

FuDaemonMachineKind
fu_daemon_machine_kind_from_string(const gchar *val)
{
    if (g_strcmp0(val, "unknown") == 0)
        return FU_DAEMON_MACHINE_KIND_UNKNOWN;
    if (g_strcmp0(val, "physical") == 0)
        return FU_DAEMON_MACHINE_KIND_PHYSICAL;
    if (g_strcmp0(val, "virtual") == 0)
        return FU_DAEMON_MACHINE_KIND_VIRTUAL;
    if (g_strcmp0(val, "container") == 0)
        return FU_DAEMON_MACHINE_KIND_CONTAINER;
    return FU_DAEMON_MACHINE_KIND_UNKNOWN;
}
