/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_PROGRESS_FLAG_NONE = 0,
    FU_PROGRESS_FLAG_GUESSED = 1<<0,
    FU_PROGRESS_FLAG_NO_PROFILE = 1<<1,
    FU_PROGRESS_FLAG_CHILD_FINISHED = 1<<2,
    FU_PROGRESS_FLAG_NO_TRACEBACK = 1<<3,
    FU_PROGRESS_FLAG_NO_SENDER = 1<<4,
    FU_PROGRESS_FLAG_UNKNOWN = G_MAXUINT64,
} FuProgressFlag;
