/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>

GByteArray *fu_struct_dpaux_dpcd_parse(const guint8 *buf, gsize bufsz, gsize offset, GError **error);
guint32 fu_struct_dpaux_dpcd_get_ieee_oui(const GByteArray *st);
gchar *fu_struct_dpaux_dpcd_get_dev_id(const GByteArray *st);
guint8 fu_struct_dpaux_dpcd_get_hw_rev(const GByteArray *st);
guint32 fu_struct_dpaux_dpcd_get_fw_ver(const GByteArray *st);
#define FU_STRUCT_DPAUX_DPCD_OFFSET_IEEE_OUI 0x0
#define FU_STRUCT_DPAUX_DPCD_OFFSET_DEV_ID 0x3
#define FU_STRUCT_DPAUX_DPCD_OFFSET_HW_REV 0x9
#define FU_STRUCT_DPAUX_DPCD_OFFSET_FW_VER 0xA
#define FU_STRUCT_DPAUX_DPCD_SIZE_DEV_ID 0x6
#define FU_STRUCT_DPAUX_DPCD_SIZE 0xD
