/* auto-generated, do not modify */
#pragma once
#include <fwupd-common.h>
typedef enum {
    FU_HID_ITEM_TAG_UNKNOWN = 0x0,
    FU_HID_ITEM_TAG_INPUT = 0x20,
    FU_HID_ITEM_TAG_OUTPUT = 0x24,
    FU_HID_ITEM_TAG_FEATURE = 0x2c,
    FU_HID_ITEM_TAG_COLLECTION = 0x28,
    FU_HID_ITEM_TAG_END_COLLECTION = 0x30,
    FU_HID_ITEM_TAG_USAGE_PAGE = 0x1,
    FU_HID_ITEM_TAG_LOGICAL_MINIMUM = 0x5,
    FU_HID_ITEM_TAG_LOGICAL_MAXIMUM = 0x9,
    FU_HID_ITEM_TAG_PHYSICAL_MINIMUM = 0xd,
    FU_HID_ITEM_TAG_PHYSICAL_MAXIMUM = 0x11,
    FU_HID_ITEM_TAG_UNIT = 0x15,
    FU_HID_ITEM_TAG_REPORT_SIZE = 0x1d,
    FU_HID_ITEM_TAG_REPORT_ID = 0x21,
    FU_HID_ITEM_TAG_REPORT_COUNT = 0x25,
    FU_HID_ITEM_TAG_PUSH = 0x29,
    FU_HID_ITEM_TAG_POP = 0x2d,
    FU_HID_ITEM_TAG_USAGE = 0x2,
    FU_HID_ITEM_TAG_USAGE_MINIMUM = 0x6,
    FU_HID_ITEM_TAG_USAGE_MAXIMUM = 0xa,
    FU_HID_ITEM_TAG_DESIGNATOR_INDEX = 0xe,
    FU_HID_ITEM_TAG_DESIGNATOR_MINIMUM = 0x12,
    FU_HID_ITEM_TAG_DESIGNATOR_MAXIMUM = 0x16,
    FU_HID_ITEM_TAG_STRING_INDEX = 0x1e,
    FU_HID_ITEM_TAG_STRING_MINIMUM = 0x22,
    FU_HID_ITEM_TAG_STRING_MAXIMUM = 0x26,
    FU_HID_ITEM_TAG_LONG = 0xf,
} FuHidItemTag;
const gchar *fu_hid_item_tag_to_string(FuHidItemTag val);
FuHidItemTag fu_hid_item_tag_from_string(const gchar *val);
typedef enum {
    FU_HID_ITEM_KIND_MAIN,
    FU_HID_ITEM_KIND_GLOBAL,
    FU_HID_ITEM_KIND_LOCAL,
} FuHidItemKind;
const gchar *fu_hid_item_kind_to_string(FuHidItemKind val);
