/* auto-generated, do not modify */
#include "config.h"

#include "fu-hailuck-struct.h"
#include "fu-byte-array.h"
#include "fu-mem-private.h"
#include "fu-string.h"

#ifdef G_LOG_DOMAIN
  #undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "FuStruct"

const gchar *
fu_hailuck_cmd_to_string(FuHailuckCmd val)
{
    if (val == FU_HAILUCK_CMD_ERASE)
        return "erase";
    if (val == FU_HAILUCK_CMD_READ_BLOCK_START)
        return "read-block-start";
    if (val == FU_HAILUCK_CMD_ATTACH)
        return "attach";
    if (val == FU_HAILUCK_CMD_WRITE_BLOCK_START)
        return "write-block-start";
    if (val == FU_HAILUCK_CMD_READ_BLOCK)
        return "read-block";
    if (val == FU_HAILUCK_CMD_DETACH)
        return "detach";
    if (val == FU_HAILUCK_CMD_WRITE_BLOCK)
        return "write-block";
    if (val == FU_HAILUCK_CMD_GET_STATUS)
        return "get-status";
    if (val == FU_HAILUCK_CMD_WRITE_TP)
        return "write-tp";
    if (val == FU_HAILUCK_CMD_I2C_CHECK_CHECKSUM)
        return "i2c-check-checksum";
    if (val == FU_HAILUCK_CMD_I2C_ENTER_BL)
        return "i2c-enter-bl";
    if (val == FU_HAILUCK_CMD_I2C_ERASE)
        return "i2c-erase";
    if (val == FU_HAILUCK_CMD_I2C_PROGRAM)
        return "i2c-program";
    if (val == FU_HAILUCK_CMD_I2C_VERIFY_BLOCK)
        return "i2c-verify-block";
    if (val == FU_HAILUCK_CMD_I2C_VERIFY_CHECKSUM)
        return "i2c-verify-checksum";
    if (val == FU_HAILUCK_CMD_I2C_PROGRAMPASS)
        return "i2c-programpass";
    if (val == FU_HAILUCK_CMD_I2C_END_PROGRAM)
        return "i2c-end-program";
    return NULL;
}
